@@ -16,6 +16,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include "../../msdoc.h"
 #include "lists.h"
 #include "olestream.h"
 #include "word97_generated.h"
@@ -605,11 +606,11 @@ ListText::~ListText()
 }
 
 
-ListInfo::ListInfo( Word97::PAP& pap, const Word97::CHP& chp, ListInfoProvider& listInfoProvider ) :
+ListInfo::ListInfo( Word97::PAP& pap, Word97::CHP& chp, ListInfoProvider& listInfoProvider ) :
     m_linkedIstd( istdNil ), m_restartingCounter( false ), m_numberFormat( 0 ),
     m_alignment( 0 ), m_isLegal( false ), m_notRestarted( false ), m_prev( false ),
     m_prevSpace( false ), m_isWord6( false ), m_followingChar( 0 ), m_lsid( 0 ),
-    m_space( 0 ), m_indent( 0 )
+    m_space( 0 ), m_indent( 0 ), m_picAutoSize( false ), m_type( NumberType )
 {
     if ( !listInfoProvider.setPAP( &pap ) ) {
         return;
@@ -628,6 +629,7 @@ ListInfo::ListInfo( Word97::PAP& pap, const Word97::CHP& chp, ListInfoProvider&
     m_startAt = listInfoProvider.startAt();
 
     if ( level ) {
+
         m_numberFormat = level->numberFormat();
         m_alignment = level->alignment();
         m_isLegal = level->isLegal();
@@ -635,10 +637,29 @@ ListInfo::ListInfo( Word97::PAP& pap, const Word97::CHP& chp, ListInfoProvider&
         m_prev = level->prev();
         m_prevSpace = level->prevSpace();
         m_isWord6 = level->isWord6();
-        m_text = listInfoProvider.text(chp);
         m_followingChar = level->followingChar();
         m_space = level->space();
         m_indent = level->indent();
+
+        if (m_numberFormat == msonfcBullet) {
+            m_type = BulletType;
+        }
+
+        // A label does NOT inherit Underline from text-properties of
+        // the paragraph mark.  A bullet does not inherit {Italics,
+        // Bold}.
+        if (m_type != NumberType) {
+            chp.fItalic = 0;
+            chp.fBold = 0;
+        }
+        chp.kul = 0;
+
+        m_text = listInfoProvider.text(chp);
+
+        if (m_text.chp->fPicBullet) {
+            m_type = PictureType;
+            m_picAutoSize = !m_text.chp->fNoAutoSize;
+        }
     } else {
         wvlog << "Bug: The ListLevel is 0!!" << endl;
     }
@@ -957,13 +978,14 @@ ListText ListInfoProvider::text(const Word97::CHP& chp) const
     Style style( chp );
 
     // Get the appropriate style for this paragraph
-//     const Style* style = m_styleSheet->styleByIndex( m_pap->istd );
-//     if ( !style ) {
-//         wvlog << "Bug: Huh, really obscure error, couldn't find the Style for the current PAP" << endl;
-//         ret.chp = new Word97::CHP;
-//     } else {
-//         ret.chp = new Word97::CHP( style->chp() );
-//     }
+    // const Style* style = m_styleSheet->styleByIndex( m_pap->istd );
+    // if ( !style ) {
+    //     wvlog << "Bug: Huh, really obscure error, couldn't find the Style for the current PAP" << endl;
+    //     ret.chp = new Word97::CHP;
+    // } else {
+    //     ret.chp = new Word97::CHP( style->chp() );
+    // }
+
     formattingListLevel()->applyGrpprlChpx( ret.chp, &style, m_styleSheet );
     return ret;
 }
