@@ -17,7 +17,7 @@
  * Copyright (C) 2005-2006 Peter Simonsson <psn@linux.se>
  * Copyright (C) 2005-2006 Sven Langkamp <sven.langkamp@gmail.com>
  * Copyright (C) 2005-2006 Inge Wallin <inge@lysator.liu.se>
- * Copyright (C) 2005-2006 Casper Boemann <cbr@boemann.dk>
+ * Copyright (C) 2005-2006 C. Boemann <cbo@boemann.dk>
  * Copyright (C) 2006 Martin Ellis <martin.ellis@kdemail.net>
  * Copyright (C) 2006 Adriaan de Groot <groot@kde.org>
  * Copyright (C) 2006 Sebastian Sauer <mail@dipe.org>
@@ -64,7 +64,7 @@
 #include "KarbonPaletteBarWidget.h"
 
 #include <KoMainWindow.h>
-#include <KoLineBorder.h>
+#include <KoShapeStroke.h>
 #include <KoCanvasControllerWidget.h>
 #include <KoDocumentResourceManager.h>
 #include <KoCanvasResourceManager.h>
@@ -82,7 +82,7 @@
 #include <KoShapeCreateCommand.h>
 #include <KoShapeDeleteCommand.h>
 #include <KoShapeReorderCommand.h>
-#include <KoShapeBorderCommand.h>
+#include <KoShapeStrokeCommand.h>
 #include <KoShapeBackgroundCommand.h>
 #include <KoParameterToPathCommand.h>
 #include <KoShapeClipCommand.h>
@@ -93,10 +93,10 @@
 #include <KoPathShape.h>
 #include <KoPathPointData.h>
 #include <KoPathCombineCommand.h>
-#include <KoPathSeparateCommand.h>
 #include <KoPathReverseCommand.h>
 #include <KoPathPointMoveCommand.h>
 #include <KoShapeTransformCommand.h>
+#include <KoShapeGroupCommand.h>
 #include <KoToolBoxFactory.h>
 #include <KoParameterShape.h>
 #include <KoRulerController.h>
@@ -327,6 +327,7 @@ KarbonView::KarbonView(KarbonPart* p, QWidget* parent)
     // layout:
     QGridLayout *layout = new QGridLayout();
     layout->setMargin(0);
+    layout->setSpacing(0);
     layout->addWidget(d->horizRuler->tabChooser(), 0, 0);
     layout->addWidget(d->horizRuler, 0, 1);
     layout->addWidget(d->vertRuler, 1, 0);
@@ -400,20 +401,20 @@ void KarbonView::dropEvent(QDropEvent *e)
             return;
 
         if (d->canvas->resourceManager()->intResource(KoCanvasResourceManager::ActiveStyleType) == KoFlake::Foreground) {
-            QList<KoShapeBorderModel*> borders;
+            QList<KoShapeStrokeModel*> strokes;
             QList<KoShape*> selectedShapes = selection->selectedShapes();
             foreach(KoShape * shape, selectedShapes) {
-                KoLineBorder * border = dynamic_cast<KoLineBorder*>(shape->border());
-                KoLineBorder * newBorder = 0;
-                if (border) {
-                    newBorder = new KoLineBorder(*border);
-                    newBorder->setColor(color);
+                KoShapeStroke * stroke = dynamic_cast<KoShapeStroke*>(shape->stroke());
+                KoShapeStroke * newStroke = 0;
+                if (stroke) {
+                    newStroke = new KoShapeStroke(*stroke);
+                    newStroke->setColor(color);
                 } else {
-                    newBorder = new KoLineBorder(1.0, color);
+                    newStroke = new KoShapeStroke(1.0, color);
                 }
-                borders.append(newBorder);
+                strokes.append(newStroke);
             }
-            d->canvas->addCommand(new KoShapeBorderCommand(selectedShapes, borders, 0));
+            d->canvas->addCommand(new KoShapeStrokeCommand(selectedShapes, strokes, 0));
         } else {
             KoColorBackground * fill = new KoColorBackground(color);
             d->canvas->addCommand(new KoShapeBackgroundCommand(selection->selectedShapes(), fill, 0));
@@ -829,8 +830,31 @@ void KarbonView::separatePath()
         }
     }
 
-    if (paths.size())
-        d->canvas->addCommand(new KoPathSeparateCommand(part(), paths));
+    if (!paths.size()) {
+        return;
+    }
+
+    KUndo2Command *cmd = new KUndo2Command;
+    cmd->setText(i18nc("(qtundo-format)", "Separate paths"));
+
+    foreach(KoPathShape* p, paths) {
+        QList<KoPathShape*> separatedPaths;
+        QList<KoShape*> newShapes;
+        if (p->separate(separatedPaths)) {
+            foreach(KoPathShape *subPath, separatedPaths) {
+                new KoShapeCreateCommand(part(), subPath, cmd);
+                newShapes << subPath;
+            }
+            // make sure we put the new subpaths into the parent
+            // of the original path
+            KoShapeGroup *parentGroup = dynamic_cast<KoShapeGroup*>(p->parent());
+            if (parentGroup) {
+                new KoShapeGroupCommand(parentGroup, newShapes, cmd);
+            }
+            new KoShapeDeleteCommand(part(), p, cmd);
+        }
+    }
+    d->canvas->addCommand(cmd);
 }
 
 void KarbonView::reversePath()
@@ -1462,7 +1486,7 @@ void KarbonView::applyStrokeToSelection()
         return;
 
     KoShape * shape = selection->firstSelectedShape();
-    d->canvas->addCommand(new KoShapeBorderCommand(selection->selectedShapes(), shape->border()));
+    d->canvas->addCommand(new KoShapeStrokeCommand(selection->selectedShapes(), shape->stroke()));
 }
 
 void KarbonView::applyPaletteColor(const KoColor &color)
@@ -1473,19 +1497,19 @@ void KarbonView::applyPaletteColor(const KoColor &color)
 
     int style = d->canvas->resourceManager()->intResource(KoCanvasResourceManager::ActiveStyleType);
     if (style == KoFlake::Foreground) {
-        QList<KoShapeBorderModel*> newStrokes;
+        QList<KoShapeStrokeModel*> newStrokes;
         foreach(KoShape *shape, selection->selectedShapes()) {
-            KoLineBorder *stroke = dynamic_cast<KoLineBorder*>(shape->border());
+            KoShapeStroke *stroke = dynamic_cast<KoShapeStroke*>(shape->stroke());
             if (stroke) {
-                // preserve border properties
-                KoLineBorder *newStroke = new KoLineBorder(*stroke);
+                // preserve stroke properties
+                KoShapeStroke *newStroke = new KoShapeStroke(*stroke);
                 newStroke->setColor(color.toQColor());
                 newStrokes << newStroke;
             } else {
-                newStrokes << new KoLineBorder(1.0, color.toQColor());
+                newStrokes << new KoShapeStroke(1.0, color.toQColor());
             }
         }
-        d->canvas->addCommand(new KoShapeBorderCommand(selection->selectedShapes(), newStrokes));
+        d->canvas->addCommand(new KoShapeStrokeCommand(selection->selectedShapes(), newStrokes));
         d->canvas->resourceManager()->setForegroundColor(color);
     } else {
         KoShapeBackground *fill = new KoColorBackground(color.toQColor());
