@@ -59,8 +59,6 @@
 
 #include <kexi_global.h>
 
-//#define MAX_FIELDS 101 //nice prime number
-
 //! used only for BLOBs
 #define DEFAULT_OBJECT_TYPE_VALUE "image"
 
@@ -267,9 +265,9 @@ void KexiTableDesignerView::initData()
 //  d->sets->clear();//default size
 // }
 
-    //add empty space
-// const int columnsCount = d->data->columnsCount();
-    for (int i = tableFieldCount; i < (int)d->sets->size(); i++) {
+    //add empty space, at least 2 times more than number of existing fields
+    uint fullSize = qMax(d->sets->size(), uint(2 * tableFieldCount));
+    for (int i = tableFieldCount; i < fullSize; i++) {
 //  KexiDB::RecordData *item = new KexiDB::RecordData(columnsCount);//3 empty fields
         d->data->append(d->data->createItem());
     }
@@ -1195,11 +1193,11 @@ KexiDB::Field * KexiTableDesignerView::buildField(const KoProperty::Set &set) co
 {
     //create a map of property values
     kDebug() << set["type"].value();
-    QHash<QByteArray, QVariant> values(KoProperty::propertyValues(set));
+    QMap<QByteArray, QVariant> values(KoProperty::propertyValues(set));
     //remove internal values, to avoid creating custom field's properties
     KexiDB::Field *field = new KexiDB::Field();
 
-    for (QMutableHashIterator<QByteArray, QVariant> it(values); it.hasNext();) {
+    for (QMutableMapIterator<QByteArray, QVariant> it(values); it.hasNext();) {
         it.next();
         const QByteArray propName(it.key());
         if (d->internalPropertyNames.contains(propName)
@@ -1931,7 +1929,7 @@ void KexiTableDesignerView::changePropertyVisibility(
 void KexiTableDesignerView::propertySetSwitched()
 {
     KexiDataTable::propertySetSwitched();
-    KexiLookupColumnPage *page = static_cast<KexiTablePart*>(window()->part())->lookupColumnPage();
+    KexiLookupColumnPage *page = qobject_cast<KexiTablePart*>(window()->part())->lookupColumnPage();
     if (page)
         page->assignPropertySet(propertySet());
 }
