@@ -39,11 +39,11 @@
 #include <ktoolbar.h>
 #include <kmenu.h>
 
-#include <qlabel.h>
-#include <qpushbutton.h>
-#include <qlayout.h>
-#include <qcheckbox.h>
-#include <qtooltip.h>
+#include <QLabel>
+#include <QPushButton>
+#include <QLayout>
+#include <QCheckBox>
+
 #include <QVBoxLayout>
 #include <QPixmap>
 #include <QFrame>
@@ -119,6 +119,7 @@ public:
     bool file_sel_shown;
     bool confirmOverwrites;
     KexiUtils::PaintBlocker* descGroupBoxPaintBlocker;
+    bool isConnectionSelected;
 };
 
 /*================================================================*/
@@ -181,6 +182,7 @@ KexiConnectionSelectorWidget::KexiConnectionSelectorWidget(
     d->remote->list->installEventFilter(this);
     d->descGroupBoxPaintBlocker = new KexiUtils::PaintBlocker(d->remote->descGroupBox);
     d->descGroupBoxPaintBlocker->setEnabled(false);
+    d->isConnectionSelected = false;
 }
 
 KexiConnectionSelectorWidget::~KexiConnectionSelectorWidget()
@@ -212,6 +214,9 @@ void KexiConnectionSelectorWidget::slotPrjTypeSelected(int id)
                 //   }
             }
             if (d->remote->list->topLevelItemCount() > 0) {
+                d->remote->list->sortByColumn(0, Qt::AscendingOrder);
+                d->remote->list->resizeColumnToContents(0); // name
+                d->remote->list->resizeColumnToContents(1); // type
                 d->remote->list->topLevelItem(0)->setSelected(true);
             }
             d->remote->descGroupBox->layout()->setMargin(2);
@@ -257,6 +262,7 @@ void KexiConnectionSelectorWidget::showSimpleConn()
         }
     }
     d->stack->setCurrentWidget(fileWidget);
+    connect(fileWidget->locationEdit()->lineEdit(), SIGNAL(textChanged(QString)), this, SLOT(slotConnectionSelected()));
 }
 
 KexiConnectionSelectorWidget::ConnectionType KexiConnectionSelectorWidget::selectedConnectionType() const
@@ -307,6 +313,7 @@ void KexiConnectionSelectorWidget::setSelectedFileName(const QString& fileName)
 void KexiConnectionSelectorWidget::slotConnectionItemExecuted(QTreeWidgetItem* item)
 {
     emit connectionItemExecuted(static_cast<ConnectionDataLVItem*>(item));
+    slotConnectionSelected();
 }
 
 void KexiConnectionSelectorWidget::slotConnectionItemExecuted()
@@ -315,6 +322,7 @@ void KexiConnectionSelectorWidget::slotConnectionItemExecuted()
     if (items.isEmpty())
         return;
     slotConnectionItemExecuted(items.first());
+    slotConnectionSelected();
 }
 
 void KexiConnectionSelectorWidget::slotConnectionSelectionChanged()
@@ -344,6 +352,7 @@ void KexiConnectionSelectorWidget::slotConnectionSelectionChanged()
         desc = item->data()->description;
     d->descGroupBoxPaintBlocker->setEnabled(desc.isEmpty());
     d->remote->descriptionLabel->setText(desc);
+    slotConnectionSelected();
     emit connectionItemHighlighted(item);
 }
 
@@ -494,3 +503,26 @@ bool KexiConnectionSelectorWidget::eventFilter(QObject* watched, QEvent* event)
     }
     return QWidget::eventFilter(watched, event);
 }
+
+void KexiConnectionSelectorWidget::slotConnectionSelected()
+{
+    QList<QTreeWidgetItem *> items;
+    QLineEdit *lineEdit;
+    switch (selectedConnectionType()) {
+    case KexiConnectionSelectorWidget::FileBased:
+        lineEdit = fileWidget->locationEdit()->lineEdit();
+        d->isConnectionSelected = !lineEdit->text().isEmpty();
+        break;
+    case KexiConnectionSelectorWidget::ServerBased:
+        items = d->remote->list->selectedItems();
+        d->isConnectionSelected = !items.isEmpty();
+        break;
+    default:;
+    }
+    emit connectionSelected (d->isConnectionSelected);
+}
+
+bool KexiConnectionSelectorWidget::hasSelectedConnection() const
+{
+    return d->isConnectionSelected;
+}
