@@ -40,10 +40,9 @@
 #include <filter/kis_filter_registry.h>
 #include <kis_global.h>
 #include <kis_image.h>
-#include <kis_iterators_pixel.h>
 #include <kis_layer.h>
 #include <kis_paint_device.h>
-#include <kis_random_accessor.h>
+#include <kis_random_accessor_ng.h>
 #include <kis_random_generator.h>
 #include <kis_selection.h>
 #include <kis_types.h>
