@@ -32,6 +32,8 @@
 #include "kis_shape_tool_helper.h"
 
 #include "kis_system_locker.h"
+#include "kis_view2.h"
+#include "kis_selection_manager.h"
 
 
 KisToolSelectRectangular::KisToolSelectRectangular(KoCanvasBase * canvas)
@@ -69,6 +71,12 @@ void KisToolSelectRectangular::finishRect(const QRectF& rect)
     if (!kisCanvas)
         return;
 
+    // If the user just clicks on the canvas deselect
+    if (rc.isEmpty()) {
+        kisCanvas->view()->selectionManager()->deselect();
+        return;
+    }
+
     KisSelectionToolHelper helper(kisCanvas, currentNode(), i18n("Rectangular Selection"));
 
     if (m_widgetHelper.selectionMode() == PIXEL_SELECTION) {
