@@ -2,7 +2,7 @@
  *  kis_tool_transform.h - part of Krita
  *
  *  Copyright (c) 2004 Boudewijn Rempt <boud@valdyas.org>
- *  Copyright (c) 2005 Casper Boemann <cbr@boemann.dk>
+ *  Copyright (c) 2005 C. Boemann <cbo@boemann.dk>
  *  Copyright (c) 2010 Marc Pegon <pe.marc@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -100,6 +100,8 @@ public:
     virtual void keyPressEvent(QKeyEvent *event);
     virtual void keyReleaseEvent(QKeyEvent *event);
 
+    virtual void resourceChanged(int key, const QVariant& res);
+
 public:
     void paint(QPainter& gc, const KoViewConverter &converter);
 
@@ -397,6 +399,8 @@ private:
 	bool m_cursorOverPoint;
 	int m_pointUnderCursor; // the id of the point in the vector
 
+    bool m_isActive;
+
 private slots:
 
     void slotSetFilter(const KoID &);
