@@ -57,22 +57,29 @@ KisToolInvocationAction::~KisToolInvocationAction()
     delete d;
 }
 
-void KisToolInvocationAction::begin(int /*shortcut*/)
+void KisToolInvocationAction::begin(int shortcut)
 {
-    if(inputManager()->tabletPressEvent()) {
-        QTabletEvent *pressEvent = inputManager()->tabletPressEvent();
-        inputManager()->toolProxy()->tabletEvent(pressEvent, d->tabletToPixel(pressEvent->hiResGlobalPos()));
-        d->useTablet = true;
-        d->pointerType = pressEvent->pointerType();
-        d->tabletDevice = pressEvent->device();
-        d->tabletZ = pressEvent->z();
-        d->tabletID = pressEvent->uniqueId();
-        setMousePosition(d->tabletToPixel(pressEvent->hiResGlobalPos()));
+    if (shortcut == ActivateShortcut) {
+        if (inputManager()->tabletPressEvent()) {
+            QTabletEvent *pressEvent = inputManager()->tabletPressEvent();
+            inputManager()->toolProxy()->tabletEvent(pressEvent, d->tabletToPixel(pressEvent->hiResGlobalPos()));
+            d->useTablet = true;
+            d->pointerType = pressEvent->pointerType();
+            d->tabletDevice = pressEvent->device();
+            d->tabletZ = pressEvent->z();
+            d->tabletID = pressEvent->uniqueId();
+            setMousePosition(d->tabletToPixel(pressEvent->hiResGlobalPos()));
 
+        } else {
+            QMouseEvent pressEvent(QEvent::MouseButtonPress, inputManager()->mousePosition().toPoint(), Qt::LeftButton, Qt::LeftButton, 0);
+            inputManager()->toolProxy()->mousePressEvent(&pressEvent, inputManager()->mousePosition());
+            setMousePosition(inputManager()->mousePosition());
+        }
     } else {
-        QMouseEvent pressEvent(QEvent::MouseButtonPress, inputManager()->mousePosition().toPoint(), Qt::LeftButton, Qt::LeftButton, 0);
-        inputManager()->toolProxy()->mousePressEvent(&pressEvent, inputManager()->mousePosition());
-        setMousePosition(inputManager()->mousePosition());
+        QKeyEvent pressEvent(QEvent::KeyPress, Qt::Key_Return, 0);
+        inputManager()->toolProxy()->keyPressEvent(&pressEvent);
+        QKeyEvent releaseEvent(QEvent::KeyRelease, Qt::Key_Return, 0);
+        inputManager()->toolProxy()->keyReleaseEvent(&releaseEvent);
     }
 }
 
@@ -90,7 +97,17 @@ void KisToolInvocationAction::end()
 
 void KisToolInvocationAction::inputEvent(QEvent* event)
 {
-    if(event->type() == QEvent::MouseMove) {
+    if(event->type() == QEvent::MouseButtonPress) {
+        QMouseEvent* mevent = static_cast<QMouseEvent*>(event);
+        setMousePosition(inputManager()->widgetToPixel(mevent->posF()));
+        d->modifiers = mevent->modifiers();
+        inputManager()->toolProxy()->mousePressEvent(mevent, mousePosition());
+    } else if(event->type() == QEvent::MouseButtonRelease) {
+        QMouseEvent* mevent = static_cast<QMouseEvent*>(event);
+        setMousePosition(inputManager()->widgetToPixel(mevent->posF()));
+        d->modifiers = mevent->modifiers();
+        inputManager()->toolProxy()->mouseReleaseEvent(mevent, mousePosition());
+    } else if(event->type() == QEvent::MouseMove) {
         QMouseEvent* mevent = static_cast<QMouseEvent*>(event);
         setMousePosition(inputManager()->widgetToPixel(mevent->posF()));
         d->modifiers = mevent->modifiers();
@@ -100,6 +117,12 @@ void KisToolInvocationAction::inputEvent(QEvent* event)
         setMousePosition(d->tabletToPixel(tevent->hiResGlobalPos()));
         d->modifiers = tevent->modifiers();
         inputManager()->toolProxy()->tabletEvent(tevent, mousePosition());
+    } else if(event->type() == QEvent::KeyPress) {
+        QKeyEvent* kevent = static_cast<QKeyEvent*>(event);
+        inputManager()->toolProxy()->keyPressEvent(kevent);
+    } else if(event->type() == QEvent::KeyRelease) {
+        QKeyEvent* kevent = static_cast<QKeyEvent*>(event);
+        inputManager()->toolProxy()->keyReleaseEvent(kevent);
     }
 }
 
