@@ -32,6 +32,7 @@
 #include <kstandardaction.h>
 #include <kactioncollection.h>
 
+#include <KoServiceProvider.h>
 #include "KoCanvasController.h"
 #include "KoChannelInfo.h"
 #include "KoIntegerMaths.h"
@@ -41,7 +42,7 @@
 #include <KoViewConverter.h>
 #include <KoSelection.h>
 #include <KoShapeManager.h>
-#include <KoLineBorder.h>
+#include <KoShapeStroke.h>
 #include <KoColorSpace.h>
 #include <KoCompositeOp.h>
 #include <KoToolProxy.h>
@@ -57,8 +58,6 @@
 #include "kis_fill_painter.h"
 #include "kis_group_layer.h"
 #include "kis_image.h"
-#include "kis_iterator_pixel_trait.h"
-#include "kis_iterators_pixel.h"
 #include "kis_layer.h"
 #include "kis_statusbar.h"
 #include "kis_paint_device.h"
@@ -80,7 +79,6 @@
 #include "kis_iterator_ng.h"
 #include "kis_clipboard.h"
 #include "kis_view2.h"
-
 #include "kis_selection_manager_p.h"
 
 
@@ -165,7 +163,7 @@ void KisSelectionManager::setup(KActionCollection * collection)
 
     m_copyToNewLayer  = new KAction(i18n("Copy Selection to New Layer"), this);
     collection->addAction("copy_selection_to_new_layer", m_copyToNewLayer);
-    m_copyToNewLayer->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_J));
+    m_copyToNewLayer->setShortcut(QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_J));
     connect(m_copyToNewLayer, SIGNAL(triggered()), this, SLOT(copySelectionToNewLayer()));
 
     m_cutToNewLayer  = new KAction(i18n("Cut Selection to New Layer"), this);
@@ -175,7 +173,7 @@ void KisSelectionManager::setup(KActionCollection * collection)
 
     m_fillForegroundColor  = new KAction(i18n("Fill with Foreground Color"), this);
     collection->addAction("fill_selection_foreground_color", m_fillForegroundColor);
-    m_fillForegroundColor->setShortcut(QKeySequence(Qt::ALT + Qt::Key_Backspace));
+    m_fillForegroundColor->setShortcut(QKeySequence(Qt::SHIFT + Qt::Key_Backspace));
     connect(m_fillForegroundColor, SIGNAL(triggered()), this, SLOT(fillForegroundColor()));
 
     m_fillBackgroundColor  = new KAction(i18n("Fill with Background Color"), this);
@@ -353,6 +351,7 @@ void KisSelectionManager::cut()
 {
     KisLayerSP layer = m_view->activeLayer();
     if (!layer) return;
+    if (!layer->isEditable()) return;
 
     if (haveShapesSelected()) {
         m_view->canvasBase()->toolProxy()->cut();
@@ -463,7 +462,7 @@ void KisSelectionManager::pasteNew()
     QRect rect = clip->exactBounds();
     if (rect.isEmpty()) return;
 
-    const QByteArray mimetype = KoDocument::readNativeFormatMimeType();
+    const QByteArray mimetype = KoServiceProvider::readNativeFormatMimeType();
     KoDocumentEntry entry = KoDocumentEntry::queryByMimeType(mimetype);
 
     KisDoc2* doc = dynamic_cast<KisDoc2*>(entry.createDoc());
@@ -542,6 +541,9 @@ void KisSelectionManager::reselect()
 
 void KisSelectionManager::clear()
 {
+    KisNodeSP node = m_view->activeNode();
+    if (!node || !node->isEditable()) return;
+
     m_view->canvasBase()->toolProxy()->deleteSelection();
     updateGUI();
 }
@@ -551,6 +553,9 @@ void KisSelectionManager::fill(const KoColor& color, bool fillWithPattern, const
     KisPaintDeviceSP device = m_view->activeDevice();
     if (!device) return;
 
+    KisNodeSP node = m_view->activeNode();
+    if (!node || !node->isEditable()) return;
+
     KisSelectionSP selection = m_view->selection();
     QRect selectedRect = selection ?
         selection->selectedRect() : m_view->image()->bounds();
@@ -693,13 +698,13 @@ void KisSelectionManager::shapeSelectionChanged()
     KoSelection * selection = shapeManager->selection();
     QList<KoShape*> selectedShapes = selection->selectedShapes();
 
-    KoLineBorder* border = new KoLineBorder(0, Qt::lightGray);
+    KoShapeStroke* border = new KoShapeStroke(0, Qt::lightGray);
     foreach(KoShape* shape, shapeManager->shapes()) {
         if (dynamic_cast<KisShapeSelection*>(shape->parent())) {
             if (selectedShapes.contains(shape))
-                shape->setBorder(border);
+                shape->setStroke(border);
             else
-                shape->setBorder(0);
+                shape->setStroke(0);
         }
     }
     updateGUI();
@@ -742,19 +747,19 @@ void KisSelectionManager::copyFromDevice(KisPaintDeviceSP device)
         // Apply selection mask.
         KisPaintDeviceSP selectionProjection = selection->projection();
         KisHLineIteratorSP layerIt = clip->createHLineIteratorNG(0, 0, r.width());
-        KisHLineConstIteratorPixel selectionIt = selectionProjection->createHLineIterator(r.x(), r.y(), r.width());
+        KisHLineConstIteratorSP selectionIt = selectionProjection->createHLineIteratorNG(r.x(), r.y(), r.width());
 
         for (qint32 y = 0; y < r.height(); y++) {
 
             for (qint32 x = 0; x < r.width(); x++) {
 
-                cs->applyAlphaU8Mask(layerIt->rawData(), selectionIt.oldRawData(), 1);
+                cs->applyAlphaU8Mask(layerIt->rawData(), selectionIt->oldRawData(), 1);
 
                 layerIt->nextPixel();
-                ++selectionIt;
+                selectionIt->nextPixel();
             }
             layerIt->nextRow();
-            selectionIt.nextRow();
+            selectionIt->nextRow();
         }
     }
 
