@@ -52,6 +52,7 @@
 #include <kis_selection_mask.h>
 #include <kis_shape_layer.h>
 #include <kis_transparency_mask.h>
+#include <kis_layer_composition.h>
 
 
 using namespace KRA;
@@ -65,7 +66,9 @@ public:
     QString imageComment; // used to be stored in the image, is now in the documentInfo block
     QMap<KisNode*, QString> layerFilenames; // temp storage during loading
     int syntaxVersion; // version of the fileformat we are loading
-
+    vKisNodeSP selectedNodes; // the nodes that were active when saving the document.
+    QMap<QString, QString> assistantsFilenames;
+    QList<KisPaintingAssistant*> assistants;
 };
 
 KisKraLoader::KisKraLoader(KisDoc2 * document, int syntaxVersion)
@@ -154,36 +157,29 @@ KisImageWSP KisKraLoader::loadXML(const KoXmlElement& element)
         image->setResolution(xres, yres);
         loadNodes(element, image, const_cast<KisGroupLayer*>(image->rootLayer().data()));
 
+        KoXmlNode child;
+        for (child = element.lastChild(); !child.isNull(); child = child.previousSibling()) {
+            KoXmlElement e = child.toElement();
+            if(e.tagName() == "compositions") {
+                loadCompositions(e, image);
+            }
+        }
+    }
+    KoXmlNode child;
+    for (child = element.lastChild(); !child.isNull(); child = child.previousSibling()) {
+        KoXmlElement e = child.toElement();
+        if (e.tagName() == "assistants") {
+            loadAssistantsList(e);
+        }
     }
-
     return image;
 }
 
 void KisKraLoader::loadBinaryData(KoStore * store, KisImageWSP image, const QString & uri, bool external)
 {
-    // Load the layers data
-    KisKraLoadVisitor visitor(image, store, m_d->layerFilenames, m_d->imageName, m_d->syntaxVersion);
 
-    if (external)
-        visitor.setExternalUri(uri);
-
-    image->rootLayer()->accept(visitor);
-
-
-    // annotations
-    // exif
+    // icc profile: if present, this overrides the profile product name loaded in loadXML.
     QString location = external ? QString::null : uri;
-    location += m_d->imageName + EXIF_PATH;
-    if (store->hasFile(location)) {
-        QByteArray data;
-        store->open(location);
-        data = store->read(store->size());
-        store->close();
-        image->addAnnotation(KisAnnotationSP(new KisAnnotation("exif", "", data)));
-    }
-
-    // icc profile
-    location = external ? QString::null : uri;
     location += m_d->imageName + ICC_PATH;
     if (store->hasFile(location)) {
         store->open(location);
@@ -194,17 +190,71 @@ void KisKraLoader::loadBinaryData(KoStore * store, KisImageWSP image, const QStr
     }
 
 
+    // Load the layers data: if there is a profile associated with a layer it will be set now.
+    KisKraLoadVisitor visitor(image, store, m_d->layerFilenames, m_d->imageName, m_d->syntaxVersion);
+
+    if (external)
+        visitor.setExternalUri(uri);
+
+    image->rootLayer()->accept(visitor);
+
+
+
+    // annotations
+    // exif
+    location = external ? QString::null : uri;
+    location += m_d->imageName + EXIF_PATH;
+    if (store->hasFile(location)) {
+        QByteArray data;
+        store->open(location);
+        data = store->read(store->size());
+        store->close();
+        image->addAnnotation(KisAnnotationSP(new KisAnnotation("exif", "", data)));
+    }
+
+
     if (m_d->document->documentInfo()->aboutInfo("title").isNull())
         m_d->document->documentInfo()->setAboutInfo("title", m_d->imageName);
     if (m_d->document->documentInfo()->aboutInfo("comment").isNull())
         m_d->document->documentInfo()->setAboutInfo("comment", m_d->imageComment);
+    loadAssistants(store, uri, external);
+}
 
+vKisNodeSP KisKraLoader::selectedNodes() const
+{
+    return m_d->selectedNodes;
+}
+
+QList<KisPaintingAssistant *> KisKraLoader::assistants() const
+{
+    return m_d->assistants;
+}
+
+void KisKraLoader::loadAssistants(KoStore *store, const QString &uri, bool external)
+{
+    QString file_path;
+    QString location;
+    QMap<int ,KisPaintingAssistantHandleSP> handleMap;
+    KisPaintingAssistant* assistant = 0;
+    QMap<QString,QString>::const_iterator loadedAssistant = m_d->assistantsFilenames.constBegin();
+    while (loadedAssistant != m_d->assistantsFilenames.constEnd()){
+        const KisPaintingAssistantFactory* factory = KisPaintingAssistantFactoryRegistry::instance()->get(loadedAssistant.value());
+        if (factory) {
+            assistant = factory->createPaintingAssistant();
+            location = external ? QString::null : uri;
+            location += m_d->imageName + ASSISTANTS_PATH;
+            file_path = location + loadedAssistant.key();
+            assistant->loadXml(store, handleMap, file_path);
+            m_d->assistants.append(assistant);
+        }
+        loadedAssistant++;
+    }
 }
 
 KisNode* KisKraLoader::loadNodes(const KoXmlElement& element, KisImageWSP image, KisNode* parent)
 {
 
-    KoXmlNode node = element.lastChild();
+    KoXmlNode node = element.firstChild();
     KoXmlNode child;
 
     QDomDocument doc;
@@ -242,7 +292,6 @@ KisNode* KisKraLoader::loadNode(const KoXmlElement& element, KisImageWSP image)
     // ALWAYS define a default value in case the property is not
     // present in the layer definition: this helps a LOT with backward
     // compatibility.
-
     QString name = element.attribute(NAME, "No Name");
 
     QUuid id = QUuid(element.attribute(UUID, QUuid().toString()));
@@ -270,6 +319,7 @@ KisNode* KisKraLoader::loadNode(const KoXmlElement& element, KisImageWSP image)
 
     bool visible = element.attribute(VISIBLE, "1") == "0" ? false : true;
     bool locked = element.attribute(LOCKED, "0") == "0" ? false : true;
+    bool collapsed = element.attribute(COLLAPSED, "0") == "0" ? false : true;
 
     // Now find out the layer type and do specific handling
     QString nodeType;
@@ -316,6 +366,7 @@ KisNode* KisKraLoader::loadNode(const KoXmlElement& element, KisImageWSP image)
 
     node->setVisible(visible);
     node->setUserLocked(locked);
+    node->setCollapsed(collapsed);
     node->setX(x);
     node->setY(y);
     node->setName(name);
@@ -332,16 +383,22 @@ KisNode* KisKraLoader::loadNode(const KoXmlElement& element, KisImageWSP image)
         layer->setCompositeOp(compositeOpName);
     }
 
-    if(node->inherits("KisPaintLayer")) {
+    if (node->inherits("KisPaintLayer")) {
         KisPaintLayer* layer            = qobject_cast<KisPaintLayer*>(node);
         QBitArray      channelLockFlags = stringToFlags(element.attribute(CHANNEL_LOCK_FLAGS, ""), colorSpace->channelCount());
         layer->setChannelLockFlags(channelLockFlags);
     }
 
-    if (element.attribute(FILE_NAME).isNull())
+    if (element.attribute(FILE_NAME).isNull()) {
         m_d->layerFilenames[node] = name;
-    else
-        m_d->layerFilenames[node] = QString(element.attribute(FILE_NAME));
+    }
+    else {
+        m_d->layerFilenames[node] = element.attribute(FILE_NAME);
+    }
+
+    if (element.hasAttribute("selected") && element.attribute("selected") == "true")  {
+        m_d->selectedNodes.append(node);
+    }
 
     return node;
 }
@@ -551,3 +608,29 @@ KisNode* KisKraLoader::loadSelectionMask(KisImageWSP image, const KoXmlElement&
 
     return mask;
 }
+
+void KisKraLoader::loadCompositions(const KoXmlElement& elem, KisImageWSP image)
+{
+    KoXmlNode child;
+    for (child = elem.firstChild(); !child.isNull(); child = child.nextSibling()) {
+        KoXmlElement e = child.toElement();
+        QString name = e.attribute("name");
+        KisLayerComposition* composition = new KisLayerComposition(image, name);
+        composition->load(e);
+        image->addComposition(composition);
+    }
+}
+
+void KisKraLoader::loadAssistantsList(const KoXmlElement &elem)
+{
+    KoXmlNode child;
+    int count = 0;
+    for (child = elem.firstChild(); !child.isNull(); child = child.nextSibling()) {
+        KoXmlElement e = child.toElement();
+        QString type = e.attribute("type");
+        QString file_name = e.attribute("filename");
+        m_d->assistantsFilenames.insert(file_name,type);
+        count++;
+
+    }
+}
