@@ -113,6 +113,26 @@ namespace KoOdfWorkaround
      * This method returns true when the width, height, x and y is given for the full circle
      */
     FLAKE_EXPORT bool fixEllipse(const QString &kind, KoShapeLoadingContext &context);
+
+    /**
+     * Calligra did use the bad strings "Formula.hidden" and "protected Formula.hidden" as values
+     * for style:cell-protect, instead of "formula-hidden" and "protected formula-hidden".
+     * This method fixes the bad strings to the correct ones.
+     */
+    FLAKE_EXPORT void fixBadFormulaHiddenForStyleCellProtect(QString &value);
+
+    /**
+     * Calligra used to store text:time-value with a "0-00-00T" prefix
+     * This method removes that prefix.
+     */
+    FLAKE_EXPORT void fixBadDateForTextTime(QString &value);
+
+    /**
+     * OpenOffice.org used to write the "rect(...)" value for fo:clip without
+     * separating the 4 offset values by commas.
+     * This method changes the string with the offset values to have commas as separators.
+     */
+    FLAKE_EXPORT void fixClipRectOffsetValuesString(QString &offsetValuesString);
 }
 
 #endif /* KOODFWORKAROUND_H */
