@@ -31,6 +31,7 @@
 #include <KoOdfStylesReader.h>
 #include <KoStoreDevice.h>
 #include <KoUnit.h>
+#include <KoViewConverter.h>
 #include <KoXmlWriter.h>
 
 #include <KDebug>
@@ -280,7 +281,7 @@ KoPatternBackground &KoPatternBackground::operator = (const KoPatternBackground
     return *this;
 }
 
-void KoPatternBackground::paint(QPainter &painter, const QPainterPath &fillPath) const
+void KoPatternBackground::paint(QPainter &painter, const KoViewConverter &converter, KoShapePaintingContext &context, const QPainterPath &fillPath) const
 {
     Q_D(const KoPatternBackground);
     if (! d->imageData)
@@ -317,10 +318,16 @@ void KoPatternBackground::paint(QPainter &painter, const QPainterPath &fillPath)
         painter.setClipPath(fillPath);
         painter.drawPixmap(targetRect, d->imageData->pixmap(sourceRect.size().toSize()), sourceRect);
     } else if (d->repeat == Stretched) {
-        QRectF sourceRect(QPointF(0, 0), d->imageData->imageSize());
-        QRectF targetRect(fillPath.boundingRect());
         painter.setClipPath(fillPath);
-        painter.drawPixmap(targetRect, d->imageData->pixmap(sourceRect.size().toSize()), sourceRect);
+        // undo conversion of the scaling so that we can use a nicely scaled image of the correct size
+        qreal zoomX, zoomY;
+        converter.zoom(&zoomX, &zoomY);
+        zoomX = zoomX ? 1 / zoomX : zoomX;
+        zoomY = zoomY ? 1 / zoomY : zoomY;
+        painter.scale(zoomX, zoomY);
+
+        QRectF targetRect = converter.documentToView(fillPath.boundingRect());
+        painter.drawPixmap(targetRect.topLeft(), d->imageData->pixmap(targetRect.size().toSize()));
     }
 
     painter.restore();
@@ -368,9 +375,9 @@ void KoPatternBackground::fillStyle(KoGenStyle &style, KoShapeSavingContext &con
         QSizeF targetSize = d->targetSize();
         QSizeF imageSize = d->imageData->imageSize();
         if (targetSize.height() != imageSize.height())
-            style.addProperty("draw:fill-image-height", QString("%1").arg(targetSize.height()));
+            style.addPropertyPt("draw:fill-image-height", targetSize.height());
         if (targetSize.width() != imageSize.width())
-            style.addProperty("draw:fill-image-width", QString("%1").arg(targetSize.width()));
+            style.addPropertyPt("draw:fill-image-width", targetSize.width());
     }
 
     KoGenStyle patternStyle(KoGenStyle::FillImageStyle /*no family name*/);
@@ -380,7 +387,6 @@ void KoPatternBackground::fillStyle(KoGenStyle &style, KoShapeSavingContext &con
     patternStyle.addAttribute("xlink:href", context.imageHref(d->imageData));
 
     QString patternStyleName = context.mainStyles().insert(patternStyle, "picture");
-    context.mainStyles().insert(style, context.isSet(KoShapeSavingContext::PresentationShape) ? "pr" : "gr");
     style.addProperty("draw:fill", "bitmap");
     style.addProperty("draw:fill-image-name", patternStyleName);
 
