@@ -52,7 +52,7 @@
 
 #include <KDebug>
 
-#include <QtGui/QColor>
+#include <QColor>
 
 
 SvgParser::SvgParser(KoDocumentResourceManager *documentResourceManager)
@@ -645,25 +645,25 @@ void SvgParser::applyStrokeStyle(KoShape *shape)
         return;
 
     if (gc->strokeType == SvgGraphicsContext::None) {
-        shape->setBorder(0);
+        shape->setStroke(0);
     } else if (gc->strokeType == SvgGraphicsContext::Solid) {
         double lineWidth = gc->stroke.lineWidth();
         QVector<qreal> dashes = gc->stroke.lineDashes();
 
-        KoLineBorder *border = new KoLineBorder(gc->stroke);
+        KoShapeStroke *stroke = new KoShapeStroke(gc->stroke);
 
         // apply line width to dashes and dash offset
         if (dashes.count() && lineWidth > 0.0) {
-            QVector<qreal> dashes = border->lineDashes();
+            QVector<qreal> dashes = stroke->lineDashes();
             for (int i = 0; i < dashes.count(); ++i)
                 dashes[i] /= lineWidth;
-            double dashOffset = border->dashOffset();
-            border->setLineStyle(Qt::CustomDashLine, dashes);
-            border->setDashOffset(dashOffset / lineWidth);
+            double dashOffset = stroke->dashOffset();
+            stroke->setLineStyle(Qt::CustomDashLine, dashes);
+            stroke->setDashOffset(dashOffset / lineWidth);
         } else {
-            border->setLineStyle(Qt::SolidLine, QVector<qreal>());
+            stroke->setLineStyle(Qt::SolidLine, QVector<qreal>());
         }
-        shape->setBorder(border);
+        shape->setStroke(stroke);
     } else if (gc->strokeType == SvgGraphicsContext::Complex) {
         // try to find referenced gradient
         SvgGradientHelper *gradient = findGradient(gc->strokeId);
@@ -679,15 +679,15 @@ void SvgParser::applyStrokeStyle(KoShape *shape)
                 delete convertedGradient;
                 brush.setTransform(gradient->transform() * gc->matrix * shape->transformation().inverted());
             }
-            KoLineBorder *border = new KoLineBorder(gc->stroke);
-            border->setLineBrush(brush);
-            border->setLineStyle(Qt::SolidLine, QVector<qreal>());
-            shape->setBorder(border);
+            KoShapeStroke *stroke = new KoShapeStroke(gc->stroke);
+            stroke->setLineBrush(brush);
+            stroke->setLineStyle(Qt::SolidLine, QVector<qreal>());
+            shape->setStroke(stroke);
         } else {
             // no referenced stroke found, use fallback color
-            KoLineBorder *border = new KoLineBorder(gc->stroke);
-            border->setLineStyle(Qt::SolidLine, QVector<qreal>());
-            shape->setBorder(border);
+            KoShapeStroke *stroke = new KoShapeStroke(gc->stroke);
+            stroke->setLineStyle(Qt::SolidLine, QVector<qreal>());
+            shape->setStroke(stroke);
         }
     }
 }
@@ -1262,9 +1262,9 @@ KoShape * SvgParser::createShapeFromElement(const KoXmlElement &element, SvgLoad
         shape->setTransformation(QTransform());
 
         // reset border
-        KoShapeBorderModel *oldBorder = shape->border();
-        shape->setBorder(0);
-        delete oldBorder;
+        KoShapeStrokeModel *oldStroke = shape->stroke();
+        shape->setStroke(0);
+        delete oldStroke;
 
         // reset fill
         KoShapeBackground *oldFill = shape->background();
@@ -1307,9 +1307,9 @@ KoShape * SvgParser::createShape(const QString &shapeID)
     shape->setTransformation(QTransform());
 
     // reset border
-    KoShapeBorderModel *oldBorder = shape->border();
-    shape->setBorder(0);
-    delete oldBorder;
+    KoShapeStrokeModel *oldStroke = shape->stroke();
+    shape->setStroke(0);
+    delete oldStroke;
 
     // reset fill
     KoShapeBackground *oldFill = shape->background();
