@@ -44,7 +44,7 @@
 #include <KoColorBackground.h>
 #include <KoGradientBackground.h>
 #include <KoPatternBackground.h>
-#include <KoLineBorder.h>
+#include <KoShapeStroke.h>
 #include <KoClipPath.h>
 #include <KoXmlWriter.h>
 
@@ -101,7 +101,7 @@ void SvgStyleWriter::saveSvgFill(KoShape *shape, SvgSavingContext &context)
 
 void SvgStyleWriter::saveSvgStroke(KoShape *shape, SvgSavingContext &context)
 {
-    const KoLineBorder * line = dynamic_cast<const KoLineBorder*>(shape->border());
+    const KoShapeStroke * line = dynamic_cast<const KoShapeStroke*>(shape->stroke());
     if (! line)
         return;
 
