@@ -734,18 +734,6 @@ void KoTableCellStyle::loadOdfProperties(KoShapeLoadingContext &context, KoStyle
         }
     }
 
-    if (styleStack.hasProperty(KoXmlNS::draw, "opacity")) {
-        const QString opacity = styleStack.property(KoXmlNS::draw, "opacity");
-        if (!opacity.isEmpty() && opacity.right(1) == "%") {
-            float percent = opacity.left(opacity.length() - 1).toFloat();
-            QBrush brush = background();
-            QColor color = brush.color();
-            color.setAlphaF(percent / 100.0);
-            brush.setColor(color);
-            setBackground(brush);
-        }
-    }
-
     QString fillStyle = styleStack.property(KoXmlNS::draw, "fill");
     if (fillStyle == "solid" || fillStyle == "hatch") {
         styleStack.save();
@@ -886,9 +874,6 @@ void KoTableCellStyle::saveOdf(KoGenStyle &style, KoShapeSavingContext &context)
                 style.addProperty("fo:background-color", backBrush.color().name(), KoGenStyle::TableCellType);
             else
                 style.addProperty("fo:background-color", "transparent", KoGenStyle::TableCellType);
-            if (!backBrush.isOpaque()) {
-                style.addProperty("draw:opacity", QString("%1%").arg(backBrush.color().alphaF() * 100.0), KoGenStyle::GraphicType);
-            }
         } else if (key == VerticalAlignment) {
             if (propertyInt(VerticalAlignment) == 0)
                 style.addProperty("style:vertical-align", "automatic", KoGenStyle::TableCellType);
