@@ -758,12 +758,6 @@ public slots:
      */
     virtual void setModified(bool _mod);
 
-    /**
-     * Called by the undo stack when the document is saved or all changes has been undone
-     * @param clean if the document's undo stack is clean or not
-     */
-    virtual void setDocumentClean(bool clean);
-
     /**
      * Set the output stream to report profile information to.
      */
@@ -958,6 +952,9 @@ private slots:
     void slotStarted(KIO::Job*);
     void startCustomDocument();
 
+    /// Called by the undo stack when undo or redo is called
+    void slotUndoStackIndexChanged(int idx);
+
 private:
 
     bool saveToStream(QIODevice *dev);
