@@ -254,7 +254,10 @@ void HorizontalPaintingStrategy::drawMeasurements(const KoRulerPrivate *d, QPain
     QRectF activeRangeRectangle;
     int numberStepPixel = qRound(d->viewConverter->documentToViewX(d->unit.fromUserValue(numberStep)));
     const bool adjustMillimeters = (d->unit.type() == KoUnit::Millimeter);
-    QFontMetrics fontMetrics(KGlobalSettings::toolBarFont());
+
+    const QFont font = KGlobalSettings::smallestReadableFont();
+    const QFontMetrics fontMetrics(font);
+    painter.setFont(font);
 
     if (numberStepPixel == 0 || numberStep == 0)
         return;
@@ -426,7 +429,7 @@ void HorizontalPaintingStrategy::drawIndents(const KoRulerPrivate *d, QPainter &
 QSize HorizontalPaintingStrategy::sizeHint()
 {
     // assumes that digits for the number only use glyphs which do not go below the baseline
-    const QFontMetrics fm(KGlobalSettings::toolBarFont());
+    const QFontMetrics fm(KGlobalSettings::smallestReadableFont());
     const int digitsHeight = fm.ascent() + 1; // +1 for baseline
     const int minimum = digitsHeight + fullStepMarkerLength + 2*measurementTextAboveBelowMargin;
 
@@ -480,7 +483,10 @@ void VerticalPaintingStrategy::drawMeasurements(const KoRulerPrivate *d, QPainte
     if (numberStepPixel <= 0)
         return;
 
-    QFontMetrics fontMetrics(KGlobalSettings::toolBarFont());
+    const QFont font = KGlobalSettings::smallestReadableFont();
+    const QFontMetrics fontMetrics(font);
+    painter.setFont(font);
+
     // Calc the longest text length
     int textLength = 0;
 
@@ -586,7 +592,7 @@ void VerticalPaintingStrategy::drawMeasurements(const KoRulerPrivate *d, QPainte
 QSize VerticalPaintingStrategy::sizeHint()
 {
     // assumes that digits for the number only use glyphs which do not go below the baseline
-    const QFontMetrics fm(KGlobalSettings::toolBarFont());
+    const QFontMetrics fm(KGlobalSettings::smallestReadableFont());
     const int digitsHeight = fm.ascent() + 1; // +1 for baseline
     const int minimum = digitsHeight + fullStepMarkerLength + 2*measurementTextAboveBelowMargin;
 
@@ -611,9 +617,8 @@ void HorizontalDistancesPaintingStrategy::drawDistanceLine(const KoRulerPrivate
     QPointF midPoint = line.pointAt(0.5);
 
     // Draw the label text
-    QFont font = KGlobalSettings::smallestReadableFont();
-    font.setPointSize(6);
-    QFontMetrics fontMetrics(font);
+    const QFont font = KGlobalSettings::smallestReadableFont();
+    const QFontMetrics fontMetrics(font);
     QString label = d->unit.toUserStringValue(
             d->viewConverter->viewToDocumentX(line.length())) + ' ' + d->unit.symbol();
     QPointF labelPosition = QPointF(midPoint.x() - fontMetrics.width(label)/2,
