@@ -22,11 +22,11 @@
 
 #include <limits.h>
 
-#include <QtGui/QImage>
-#include <QtCore/QHash>
-#include <QtCore/QVector>
-#include <QtCore/QList>
-#include <QtCore/QBitArray>
+#include <QImage>
+#include <QHash>
+#include <QVector>
+#include <QList>
+#include <QBitArray>
 
 #include "KoColorSpaceConstants.h"
 #include "KoColorConversionTransformation.h"
@@ -118,7 +118,7 @@ public:
     virtual quint32 channelCount() const = 0;
 
     /**
-     * The total number of color channels (excludes alpha and substance) for a single
+     * The total number of color channels (excludes alpha) for a single
      * pixel in this color model.
      */
     virtual quint32 colorChannelCount() const = 0;
@@ -129,13 +129,11 @@ public:
      *
      * @param color if true, set all color channels to true
      * @param alpha if true, set all alpha channels to true
-     * @param substance if true, set all substance channels to true
-     * @param substrate if true, set all substrate channels to true
      *
      * The order of channels is the colorspace descriptive order,
      * not the pixel order.
      */
-    QBitArray channelFlags(bool color = true, bool alpha = false, bool substance = false, bool substrate = false) const;
+    QBitArray channelFlags(bool color = true, bool alpha = false) const;
 
     /**
      * The size in bytes of a single pixel in this color model
@@ -593,4 +591,12 @@ protected:
     Private * const d;
 };
 
+inline QDebug operator<<(QDebug dbg, const KoColorSpace *cs)
+{
+    dbg.nospace() << cs->name() << " (" << cs->colorModelId().id() << "," << cs->colorDepthId().id() << " )";
+
+    return dbg.space();
+}
+
+
 #endif // KOCOLORSPACE_H
