@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
- * Copyright (c) 2007 Casper Boemann <cbr@boemann.dk>
+ * Copyright (c) 2007 C. Boemann <cbo@boemann.dk>
  * Copyright (C) 2007 Fredy Yanardi <fyanardi@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -25,6 +25,8 @@
 #include "KoColorSlider.h"
 #include "KoCheckerBoardPainter.h"
 #include "KoColorSpaceRegistry.h"
+#include <KoResourceServer.h>
+#include <KoResourceServerProvider.h>
 
 #include <QPainter>
 #include <QWidgetAction>
@@ -43,7 +45,7 @@
 class KoColorPopupAction::KoColorPopupActionPrivate
 {
 public:
-    KoColorPopupActionPrivate() 
+    KoColorPopupActionPrivate()
         : colorSetWidget(0), colorChooser(0), opacitySlider(0), menu(0), checkerPainter(4)
         , showFilter(true), applyMode(true)
     {}
@@ -55,7 +57,7 @@ public:
         delete opacitySlider;
         delete menu;
     }
-    
+
     KoColor currentColor;
     KoColor buddyColor;
 
@@ -76,6 +78,13 @@ KoColorPopupAction::KoColorPopupAction(QObject *parent)
     QWidget *widget = new QWidget(d->menu);
     QWidgetAction *wdgAction = new QWidgetAction(d->menu);
     d->colorSetWidget = new KoColorSetWidget(widget);
+
+    KoResourceServer<KoColorSet>* srv = KoResourceServerProvider::instance()->paletteServer();
+    QList<KoColorSet*> palettes = srv->resources();
+    if (!palettes.empty()) {
+        d->colorSetWidget->setColorSet(palettes.first());
+    }
+
     d->colorChooser = new KoTriangleColorSelector( widget );
     // prevent mouse release on color selector from closing popup
     d->colorChooser->setAttribute( Qt::WA_NoMousePropagation );
@@ -102,9 +111,9 @@ KoColorPopupAction::KoColorPopupAction(QObject *parent)
 
     connect(d->colorSetWidget, SIGNAL(colorChanged(const KoColor &, bool)), this, SLOT(colorWasSelected(const KoColor &, bool)));
 
-    connect( d->colorChooser, SIGNAL( colorChanged( const QColor &) ), 
+    connect( d->colorChooser, SIGNAL( colorChanged( const QColor &) ),
              this, SLOT( colorWasEdited( const QColor &) ) );
-    connect( d->opacitySlider, SIGNAL(valueChanged(int)), 
+    connect( d->opacitySlider, SIGNAL(valueChanged(int)),
              this, SLOT(opacityWasChanged(int)));
 }
 
@@ -162,7 +171,7 @@ void KoColorPopupAction::updateIcon( )
     {
         pm = QImage(iconSize, QImage::Format_ARGB32_Premultiplied);
         pm.fill(Qt::transparent);
-        // there was no icon set so we assume 
+        // there was no icon set so we assume
         // that we create an icon from the current color
         d->applyMode = false;
     }
