@@ -88,8 +88,10 @@ KoResourceItemChooser::KoResourceItemChooser(KoAbstractResourceServerAdapter * r
     d->view->setModel(d->model);
     d->view->setItemDelegate( new KoResourceItemDelegate( this ) );
     d->view->setSelectionMode( QAbstractItemView::SingleSelection );
-    connect( d->view, SIGNAL(clicked( const QModelIndex & ) ),
+    connect(d->view, SIGNAL(clicked( const QModelIndex & ) ),
              this, SLOT(activated ( const QModelIndex & ) ) );
+    connect(d->view, SIGNAL(currentResourceChanged( const QModelIndex &)),
+            this, SLOT(activated(const QModelIndex &)));
 
     d->previewScroller = new QScrollArea(this);
     d->previewScroller->setWidgetResizable(true);
@@ -164,8 +166,8 @@ KoResourceItemChooser::KoResourceItemChooser(KoAbstractResourceServerAdapter * r
     d->tagOpLineEdit->setEnabled( false );
     d->tagOpLineEdit->hide();
 
-    connect( d->tagOpLineEdit, SIGNAL(returnPressed(QString)), this, SLOT(tagOpLineEditActivated(QString)));
-    connect( d->tagOpLineEdit, SIGNAL(textChanged(QString)), this, SLOT(tagOpLineEditTextChanged(QString)));
+    connect(d->tagOpLineEdit, SIGNAL(returnPressed(QString)), this, SLOT(tagOpLineEditActivated(QString)));
+    connect(d->tagOpLineEdit, SIGNAL(textChanged(QString)), this, SLOT(tagOpLineEditTextChanged(QString)));
 
     layout->addWidget( d->tagOpLineEdit );
     layout->addLayout( buttonLayout );
@@ -560,6 +562,11 @@ QStringList KoResourceItemChooser::getTagNamesList(QString lineEditText)
     return tagNamesList;
 }
 
+KoResourceItemView *KoResourceItemChooser::itemView()
+{
+    return d->view;
+}
+
 QStringList KoResourceItemChooser::getTaggedResourceFileNames(QString lineEditText)
 {
     return d->model->resourceServerAdapter()->searchTag(lineEditText);
