@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-  Copyright (C) 2006 -2010 Dag Andersen <danders@get2net.dk>
+  Copyright (C) 2006 -2010, 2012 Dag Andersen <danders@get2net.dk>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -20,6 +20,7 @@
 #include "kptviewbase.h"
 #include "kptitemmodelbase.h"
 #include "kptproject.h"
+#include "kptdebug.h"
 
 #include <kaction.h>
 #include <kicon.h>
@@ -32,9 +33,11 @@
 #include <KoShape.h>
 #include <KoPageLayoutWidget.h>
 #include <KoPagePreviewWidget.h>
+#include "KoUnit.h"
 
 #include <QAbstractItemModel>
 #include <QAbstractProxyModel>
+#include <QSortFilterProxyModel>
 #include <QHeaderView>
 #include <QPoint>
 #include <QScrollBar>
@@ -44,20 +47,82 @@
 #include <QPainter>
 #include <QMenu>
 
+
 namespace KPlato
 {
 
+bool PrintingOptions::loadXml( KoXmlElement &element )
+{
+    KoXmlElement e;
+    forEachElement( e, element ) {
+        if ( e.tagName() == "header" ) {
+            headerOptions.group = e.attribute( "group", "0" ).toInt();
+            headerOptions.project = static_cast<Qt::CheckState>( e.attribute( "project", "0" ).toInt() );
+            headerOptions.date = static_cast<Qt::CheckState>( e.attribute( "date", "0" ).toInt() );
+            headerOptions.manager = static_cast<Qt::CheckState>( e.attribute( "manager", "0" ).toInt() );
+            headerOptions.page = static_cast<Qt::CheckState>( e.attribute( "page", "0" ).toInt() );
+        } else if ( e.tagName() == "footer" ) {
+            footerOptions.group = e.attribute( "group", "0" ).toInt();
+            footerOptions.project = static_cast<Qt::CheckState>( e.attribute( "project", "0" ).toInt() );
+            footerOptions.date = static_cast<Qt::CheckState>( e.attribute( "date", "0" ).toInt() );
+            footerOptions.manager = static_cast<Qt::CheckState>( e.attribute( "manager", "0" ).toInt() );
+            footerOptions.page = static_cast<Qt::CheckState>( e.attribute( "page", "0" ).toInt() );
+        }
+    }
+    return true;
+}
+
+void PrintingOptions::saveXml( QDomElement &element ) const
+{
+    QDomElement me = element.ownerDocument().createElement( "printing-options" );
+    element.appendChild( me );
+
+    QDomElement h = me.ownerDocument().createElement( "header" );
+    me.appendChild( h );
+    h.setAttribute( "group", headerOptions.group );
+    h.setAttribute( "project", headerOptions.project );
+    h.setAttribute( "date", headerOptions.date );
+    h.setAttribute( "manager", headerOptions.manager );
+    h.setAttribute( "page", headerOptions.page );
+
+    QDomElement f = me.ownerDocument().createElement( "footer" );
+    me.appendChild( f );
+    f.setAttribute( "group", footerOptions.group );
+    f.setAttribute( "project", footerOptions.project );
+    f.setAttribute( "date", footerOptions.date );
+    f.setAttribute( "manager", footerOptions.manager );
+    f.setAttribute( "page", footerOptions.page );
+}
+
+//----------------------
 PrintingHeaderFooter::PrintingHeaderFooter( const PrintingOptions &opt, QWidget *parent )
     : QWidget( parent )
 {
     setupUi( this );
     setWindowTitle( i18n("Header and Footer" ));
     setOptions( opt );
+
+    connect(ui_header, SIGNAL(toggled(bool)), SLOT(slotChanged()));
+    connect(ui_headerProject, SIGNAL(stateChanged(int)), SLOT(slotChanged()));
+    connect(ui_headerPage, SIGNAL(stateChanged(int)), SLOT(slotChanged()));
+    connect(ui_headerManager, SIGNAL(stateChanged(int)), SLOT(slotChanged()));
+    connect(ui_headerDate, SIGNAL(stateChanged(int)), SLOT(slotChanged()));
+
+    connect(ui_footer, SIGNAL(toggled(bool)), SLOT(slotChanged()));
+    connect(ui_footerProject, SIGNAL(stateChanged(int)), SLOT(slotChanged()));
+    connect(ui_footerPage, SIGNAL(stateChanged(int)), SLOT(slotChanged()));
+    connect(ui_footerManager, SIGNAL(stateChanged(int)), SLOT(slotChanged()));
+    connect(ui_footerDate, SIGNAL(stateChanged(int)), SLOT(slotChanged()));
 }
 
 PrintingHeaderFooter::~PrintingHeaderFooter()
 {
-    //kDebug();
+    //kDebug(planDbg());
+}
+
+void PrintingHeaderFooter::slotChanged()
+{
+    emit changed( options() );
 }
 
 void PrintingHeaderFooter::setOptions( const PrintingOptions &options )
@@ -79,7 +144,7 @@ void PrintingHeaderFooter::setOptions( const PrintingOptions &options )
 
 PrintingOptions PrintingHeaderFooter::options() const
 {
-    //kDebug();
+    //kDebug(planDbg());
     PrintingOptions opt;
     opt.headerOptions.group = ui_header->isChecked();
     opt.headerOptions.project = ui_headerProject->checkState();
@@ -103,6 +168,10 @@ PrintingDialog::PrintingDialog( ViewBase *view )
     setPrinterPageLayout();
 }
 
+PrintingDialog::~PrintingDialog()
+{
+}
+
 QAbstractPrintDialog::PrintDialogOptions PrintingDialog::printDialogOptions() const
 {
     return QAbstractPrintDialog::PrintToFile |
@@ -138,12 +207,12 @@ void PrintingDialog::setPrinterPageLayout()
 
 void PrintingDialog::startPrinting(RemovePolicy removePolicy )
 {
+    // FIXME: this triggers a crash in QPrintPreviewDialog if printing options != default
     PrintingOptions opt;
     if ( m_widget ) {
         opt = m_widget->options();
     }
     setPrintingOptions( opt );
-    setPrinterPageLayout();
     KoPrintingDialog::startPrinting( removePolicy );
 }
 
@@ -153,17 +222,14 @@ QWidget *PrintingDialog::createPageLayoutWidget() const
     widget->setWindowTitle( i18nc( "@title:tab", "Page Layout" ) );
 
     QHBoxLayout *lay = new QHBoxLayout(widget);
-    lay->setMargin(0);
-    widget->setLayout(lay);
 
     KoPageLayoutWidget *w = new KoPageLayoutWidget( widget, m_view->pageLayout() );
     w->showPageSpread( false );
-    w->layout()->setMargin( 0 );
-    lay->addWidget( w );
+    lay->addWidget( w, 1 );
 
     KoPagePreviewWidget *prev = new KoPagePreviewWidget( widget );
     prev->setPageLayout( m_view->pageLayout() );
-    lay->addWidget( prev );
+    lay->addWidget( prev, 1 );
 
     connect(w, SIGNAL(layoutChanged(const KoPageLayout&)), m_view, SLOT(setPageLayout(const KoPageLayout&)));
 
@@ -174,8 +240,9 @@ QWidget *PrintingDialog::createPageLayoutWidget() const
 
 QList<QWidget*> PrintingDialog::createOptionWidgets() const
 {
-    //kDebug();
+    //kDebug(planDbg());
     PrintingHeaderFooter *w = new PrintingHeaderFooter( printingOptions() );
+    connect(w, SIGNAL(changed(const PrintingOptions&)), m_view, SLOT(setPrintingOptions(const PrintingOptions&)));
     const_cast<PrintingDialog*>( this )->m_widget = w;
 
     return QList<QWidget*>() << w;
@@ -364,6 +431,16 @@ KoDocument *ViewBase::part() const
      return koDocument();
 }
 
+KoPageLayout ViewBase::pageLayout() const
+{
+    return m_pagelayout;
+}
+
+void ViewBase::setPageLayout( const KoPageLayout &layout )
+{
+    m_pagelayout = layout;
+}
+
 bool ViewBase::isActive() const
 {
     if ( hasFocus() ) {
@@ -384,7 +461,7 @@ void ViewBase::updateReadWrite( bool readwrite )
 
 void ViewBase::setGuiActive( bool active ) // virtual slot
 {
-    //kDebug()<<active;
+    //kDebug(planDbg())<<active;
     emit guiActivated( this, active );
 }
 
@@ -402,7 +479,7 @@ KoPrintJob *ViewBase::createPrintJob()
 
 void ViewBase::slotHeaderContextMenuRequested( const QPoint &pos )
 {
-    kDebug();
+    kDebug(planDbg());
     QList<QAction*> lst = contextActionList();
     if ( ! lst.isEmpty() ) {
         QMenu::exec( lst, pos, lst.first() );
@@ -426,6 +503,42 @@ void ViewBase::slotOptionsFinished( int result )
     }
 }
 
+bool ViewBase::loadContext( const KoXmlElement &context )
+{
+    KoXmlElement me;
+    forEachElement( me, context ) {
+        if ( me.tagName() == "page-layout" ) {
+            m_pagelayout.format = KoPageFormat::formatFromString( me.attribute( "format" ) );
+            m_pagelayout.orientation = me.attribute( "orientation" ) == "landscape" ? KoPageFormat::Landscape : KoPageFormat::Portrait;
+            m_pagelayout.width = me.attribute( "width", "0.0" ).toDouble();
+            m_pagelayout.height = me.attribute( "height", "0.0" ).toDouble();
+            m_pagelayout.leftMargin = me.attribute( "left-margin", QString::number( MM_TO_POINT( 20.0 ) ) ).toDouble();
+            m_pagelayout.rightMargin = me.attribute( "right-margin", QString::number( MM_TO_POINT( 20.0 ) ) ).toDouble();
+            m_pagelayout.topMargin = me.attribute( "top-margin", QString::number( MM_TO_POINT( 20.0 ) ) ).toDouble();
+            m_pagelayout.bottomMargin = me.attribute( "bottom-margin", QString::number( MM_TO_POINT( 20.0 ) ) ).toDouble();
+        } else if ( me.tagName() == "printing-options" ) {
+            m_printingOptions.loadXml( me );
+        }
+    }
+    return true;
+}
+
+void ViewBase::saveContext( QDomElement &context ) const
+{
+    QDomElement me = context.ownerDocument().createElement( "page-layout" );
+    context.appendChild( me );
+    me.setAttribute( "format", KoPageFormat::formatString( m_pagelayout.format ) );
+    me.setAttribute( "orientation", m_pagelayout.orientation == KoPageFormat::Portrait ? "portrait" : "landscape" );
+    me.setAttribute( "width", m_pagelayout.width );
+    me.setAttribute( "height",m_pagelayout. height );
+    me.setAttribute( "left-margin", m_pagelayout.leftMargin );
+    me.setAttribute( "right-margin", m_pagelayout.rightMargin );
+    me.setAttribute( "top-margin", m_pagelayout.topMargin );
+    me.setAttribute( "bottom-margin", m_pagelayout.bottomMargin );
+
+    m_printingOptions.saveXml( context );
+}
+
 //----------------------
 TreeViewPrintingDialog::TreeViewPrintingDialog( ViewBase *view, TreeViewBase *treeview, Project *project )
     : PrintingDialog( view ),
@@ -447,7 +560,7 @@ int TreeViewPrintingDialog::documentLastPage() const
 
 int TreeViewPrintingDialog::firstRow( int page ) const
 {
-    kDebug()<<page;
+    kDebug(planDbg())<<page;
     int pageNumber = page - documentFirstPage();
     QHeaderView *mh = m_tree->header();
     int height = mh->height();
@@ -478,7 +591,7 @@ int TreeViewPrintingDialog::firstRow( int page ) const
         row = 0;
         while ( idx.isValid() ) {
             if ( row >= rowsPrPage * pageNumber ) {
-                kDebug()<<page<<pageNumber;
+                kDebug(planDbg())<<page<<pageNumber;
                 break;
             }
             ++row;
@@ -488,7 +601,7 @@ int TreeViewPrintingDialog::firstRow( int page ) const
             row = -1;
         }
     }
-    kDebug()<<row<<rowsPrPage;
+    kDebug(planDbg())<<row<<rowsPrPage;
     return row;
 }
 
@@ -517,7 +630,7 @@ void TreeViewPrintingDialog::printPage( int page, QPainter &painter )
 
     QAbstractItemModel *model = m_tree->model();
 
-    kDebug()<<pageRect<<paperRect;
+    kDebug(planDbg())<<pageRect<<paperRect;
 
     painter.translate( pageRect.topLeft() );
 
@@ -556,19 +669,19 @@ void TreeViewPrintingDialog::printPage( int page, QPainter &painter )
             QRect r( mh->sectionPosition( i ), 0, mh->sectionSize( i ), height );
             painter.drawRect( r );
             painter.drawText( r, align, text );
-            //kDebug()<<text<<r<<r.left() * sx<<align;
+            //kDebug(planDbg())<<text<<r<<r.left() * sx<<align;
         }
-        //kDebug()<<text<<"hidden="<<h->isSectionHidden( i )<<h->sectionPosition( i );
+        //kDebug(planDbg())<<text<<"hidden="<<h->isSectionHidden( i )<<h->sectionPosition( i );
     }
     if ( m_firstRow == -1 ) {
-        kDebug()<<"No data";
+        kDebug(planDbg())<<"No data";
         painter.restore();
         return;
     }
     painter.setBrush( QBrush() );
     QModelIndex idx = model->index( m_firstRow, 0, QModelIndex() );
     int numRows = 0;
-    //kDebug()<<page<<rowsPrPage;
+    //kDebug(planDbg())<<page<<rowsPrPage;
     while ( idx.isValid() && numRows < rowsPrPage ) {
         painter.translate( 0, height );
         h += height;
@@ -640,13 +753,13 @@ void TreeViewBase::createItemDelegates( ItemModelBase *model )
 
 void TreeViewBase::slotHeaderContextMenuRequested( const QPoint& pos )
 {
-    //kDebug();
+    //kDebug(planDbg());
     emit headerContextMenuRequested( header()->mapToGlobal( pos ) );
 }
 
 void TreeViewBase::setColumnsHidden( const QList<int> &lst )
 {
-    //kDebug()<<m_hideList;
+    //kDebug(planDbg())<<m_hideList;
     int prev = -1;
     QList<int> xlst;
     foreach ( int c, lst ) {
@@ -726,7 +839,7 @@ QModelIndex TreeViewBase::lastEditable( int row, const QModelIndex &parent )
 // Reimplemented to fix qt bug 160083: Doesn't scroll horisontally.
 void TreeViewBase::scrollTo(const QModelIndex &index, ScrollHint hint)
 {
-    //kDebug()<<objectName()<<index<<hint;
+    //kDebug(planDbg())<<objectName()<<index<<hint;
     if ( ! hasFocus() ) {
         return;
     }
@@ -752,7 +865,7 @@ void TreeViewBase::scrollTo(const QModelIndex &index, ScrollHint hint)
 
 void TreeViewBase::focusInEvent(QFocusEvent *event)
 {
-    //kDebug()<<event->reason();
+    //kDebug(planDbg())<<event->reason();
     QAbstractScrollArea::focusInEvent(event); //NOTE: not QTreeView
     if ( event->reason() == Qt::MouseFocusReason ) {
         return;
@@ -777,7 +890,7 @@ void TreeViewBase::focusInEvent(QFocusEvent *event)
  */
 void TreeViewBase::keyPressEvent(QKeyEvent *event)
 {
-    //kDebug()<<objectName()<<event->key()<<","<<m_arrowKeyNavigation;
+    //kDebug(planDbg())<<objectName()<<event->key()<<","<<m_arrowKeyNavigation;
     if ( !m_arrowKeyNavigation ) {
         QTreeView::keyPressEvent( event );
         return;
@@ -863,7 +976,7 @@ void TreeViewBase::mousePressEvent(QMouseEvent *event)
     // If  the mouse is pressed outside any item, the current item should be/remain selected
     QPoint pos = event->pos();
     QModelIndex index = indexAt(pos);
-    kDebug()<<index<<event->pos();
+    kDebug(planDbg())<<index<<event->pos();
     if ( ! index.isValid() ) {
         index = selectionModel()->currentIndex();
         if ( index.isValid() && ! selectionModel()->isSelected( index ) ) {
@@ -871,7 +984,7 @@ void TreeViewBase::mousePressEvent(QMouseEvent *event)
             QMouseEvent e( event->type(), pos, mapToGlobal( pos ), event->button(), event->buttons(), event->modifiers() );
             QTreeView::mousePressEvent( &e );
             event->setAccepted( e.isAccepted() );
-            kDebug()<<index<<e.pos();
+            kDebug(planDbg())<<index<<e.pos();
         }
         return;
     }
@@ -880,7 +993,7 @@ void TreeViewBase::mousePressEvent(QMouseEvent *event)
 
 void TreeViewBase::closeEditor(QWidget *editor, QAbstractItemDelegate::EndEditHint hint)
 {
-    //kDebug()<<editor<<hint;
+    //kDebug(planDbg())<<editor<<hint;
     ItemDelegate *delegate = ::qobject_cast<ItemDelegate*>( sender() );
     if ( delegate == 0 ) {
         kWarning()<<"Not a KPlato::ItemDelegate, try standard treatment"<<editor<<hint;
@@ -907,12 +1020,12 @@ void TreeViewBase::closeEditor(QWidget *editor, QAbstractItemDelegate::EndEditHi
             index = moveToEditable( currentIndex(), MoveUp );
             break;
         default:
-            //kDebug()<<"Standard treatment"<<editor<<hint;
+            //kDebug(planDbg())<<"Standard treatment"<<editor<<hint;
             return QTreeView::closeEditor( editor, hint ); // standard treatment
     }
     if (index.isValid()) {
         QItemSelectionModel::SelectionFlags flags = QItemSelectionModel::ClearAndSelect | selectionBehaviorFlags();
-        //kDebug()<<flags;
+        //kDebug(planDbg())<<flags;
         QPersistentModelIndex persistent(index);
         selectionModel()->setCurrentIndex(persistent, flags);
         // currentChanged signal would have already started editing
@@ -928,7 +1041,7 @@ QModelIndex TreeViewBase::moveToEditable( const QModelIndex &index, CursorAction
     do {
         ix = moveCursor( ix, cursorAction );
     } while ( ix.isValid() &&  ! ( model()->flags( ix ) & Qt::ItemIsEditable ) );
-    //kDebug()<<ix;
+    //kDebug(planDbg())<<ix;
     if ( ! ix.isValid() ) {
         switch ( cursorAction ) {
             case MovePrevious:
@@ -951,7 +1064,7 @@ QModelIndex TreeViewBase::moveToEditable( const QModelIndex &index, CursorAction
 QModelIndex TreeViewBase::moveCursor( CursorAction cursorAction, Qt::KeyboardModifiers modifiers )
 {
     QModelIndex current = currentIndex();
-    //kDebug()<<cursorAction<<current;
+    //kDebug(planDbg())<<cursorAction<<current;
     if (!current.isValid()) {
         return QTreeView::moveCursor( cursorAction, modifiers );
     }
@@ -973,7 +1086,7 @@ QModelIndex TreeViewBase::moveCursor( const QModelIndex &index, CursorAction cur
             // that has a column in current.column()
             ix = indexBelow( current );
             while ( ix.isValid() && col >= model()->columnCount(ix.parent()) ) {
-                //kDebug()<<col<<model()->columnCount(ix.parent())<<ix;
+                //kDebug(planDbg())<<col<<model()->columnCount(ix.parent())<<ix;
                 ix = indexBelow( ix );
             }
             if ( ix.isValid() ) {
@@ -1062,7 +1175,7 @@ QModelIndex TreeViewBase::moveCursor( const QModelIndex &index, CursorAction cur
 
 void TreeViewBase::contextMenuEvent ( QContextMenuEvent *event )
 {
-    //kDebug();
+    //kDebug(planDbg());
     emit contextMenuRequested( indexAt(event->pos()), event->globalPos() );
 }
 
@@ -1113,10 +1226,10 @@ int TreeViewBase::section( int col ) const
 
 void TreeViewBase::dragMoveEvent(QDragMoveEvent *event)
 {
-    //kDebug();
+    //kDebug(planDbg());
     if (dragDropMode() == InternalMove
         && (event->source() != this || !(event->possibleActions() & Qt::MoveAction))) {
-        //kDebug()<<"Internal:"<<event->isAccepted();
+        //kDebug(planDbg())<<"Internal:"<<event->isAccepted();
         return;
     }
     QTreeView::dragMoveEvent( event );
@@ -1124,17 +1237,17 @@ void TreeViewBase::dragMoveEvent(QDragMoveEvent *event)
         if ( ! m_acceptDropsOnView ) {
             event->ignore();
         }
-        //kDebug()<<"On viewport:"<<event->isAccepted();
+        //kDebug(planDbg())<<"On viewport:"<<event->isAccepted();
         return;
     }
     QModelIndex index = indexAt( event->pos() );
     if ( ! index.isValid() ) {
         event->ignore();
-        //kDebug()<<"Invalid index:"<<event->isAccepted();
+        //kDebug(planDbg())<<"Invalid index:"<<event->isAccepted();
         return;
     }
     emit dropAllowed( index, dropIndicatorPosition(), event );
-    //kDebug()<<event->isAccepted();
+    //kDebug(planDbg())<<event->isAccepted();
 }
 
 QModelIndex TreeViewBase::firstVisibleIndex( const QModelIndex &idx ) const
@@ -1151,33 +1264,33 @@ QModelIndex TreeViewBase::firstVisibleIndex( const QModelIndex &idx ) const
 
 bool TreeViewBase::loadContext( const QMetaEnum &map, const KoXmlElement &element )
 {
-    //kDebug()<<objectName();
+    //kDebug(planDbg())<<objectName();
     header()->setStretchLastSection( (bool)( element.attribute( "stretch-last-column", "1" ).toInt() ) );
     KoXmlElement e = element.namedItem( "columns" ).toElement();
     if ( ! e.isNull() ) {
         if ( ! map.isValid() ) {
             // try numbers
-            kDebug()<<"invalid map";
+            kDebug(planDbg())<<"invalid map";
             for ( int i = model()->columnCount() - 1; i >= 0; --i ) {
                 QString s = e.attribute( QString( "column-%1" ).arg( i ), "" );
                 if ( s == "hidden" ) {
                     hideColumn( i );
                 } else if ( s == "shown" ) {
                     showColumn( i );
-                } else kDebug()<<objectName()<<"Unknown column:"<<s;
+                } else kDebug(planDbg())<<objectName()<<"Unknown column:"<<s;
             }
         } else {
             for ( int i = model()->columnCount() - 1; i >= 0; --i ) {
                 QString n = map.key( i );
-                //kDebug()<<i<<"="<<n;
+                //kDebug(planDbg())<<i<<"="<<n;
                 if ( ! n.isEmpty() ) {
                     QString s = e.attribute( n, "" );
                     if ( s == "hidden" ) {
                         hideColumn( i );
                     } else if ( s == "shown" ) {
                         showColumn( i );
-                    } else kDebug()<<objectName()<<"Unknown column:"<<s;
-                } else kDebug()<<"Column not in enum:"<<i;
+                    } else kDebug(planDbg())<<objectName()<<"Unknown column:"<<s;
+                } else kDebug(planDbg())<<"Column not in enum:"<<i;
             }
         }
     }
@@ -1196,14 +1309,21 @@ bool TreeViewBase::loadContext( const QMetaEnum &map, const KoXmlElement &elemen
                 }
             }
         } else {
+            QMap<int, int > m; // QMap<destination, column>
             for ( int i = 0; i < h->count(); ++i ) {
-                QString n = map.key( i );
-                if ( ! n.isEmpty() ) {
-                    int col = map.keyToValue( e.attribute( s.arg( i ), "" ).toUtf8() );
-                    if ( col >= 0 && col < h->count() ) {
-                        header()->moveSection( h->visualIndex( col ), i );
-                    }
+                QString n = e.attribute( s.arg( i ) );
+                if ( n.isEmpty() ) {
+                    continue;
                 }
+                int col = map.keyToValue( n.toUtf8() );
+                if ( col >= 0 && col < h->count() ) {
+                    m.insert( i, col );
+                }
+            }
+            for ( QMap<int, int>::const_iterator it = m.constBegin(); it != m.constEnd(); ++it ) {
+                QString n = e.attribute( s.arg( it.key() ) );
+                int current = h->visualIndex( it.value() );
+                header()->moveSection( current, it.key() );
             }
         }
     }
@@ -1212,18 +1332,18 @@ bool TreeViewBase::loadContext( const QMetaEnum &map, const KoXmlElement &elemen
 
 void TreeViewBase::saveContext( const QMetaEnum &map, QDomElement &element ) const
 {
-    //kDebug()<<objectName();
+    //kDebug(planDbg())<<objectName();
     element.setAttribute( "stretch-last-column", header()->stretchLastSection() );
     QDomElement e = element.ownerDocument().createElement( "columns" );
     element.appendChild( e );
     for ( int i = 0; i < model()->columnCount(); ++i ) {
         bool h = isColumnHidden( i );
         if ( ! map.isValid() ) {
-            kDebug()<<"invalid map";
+            kDebug(planDbg())<<"invalid map";
             e.setAttribute( QString( "column-%1" ).arg( i ), h ? "hidden" : "shown" );
         } else {
             QString n = map.key( i );
-            //kDebug()<<i<<"="<<n;
+            //kDebug(planDbg())<<i<<"="<<n;
             if ( ! n.isEmpty() ) {
                 e.setAttribute( n, h ? "hidden" : "shown" );
             }
@@ -1246,6 +1366,17 @@ void TreeViewBase::saveContext( const QMetaEnum &map, QDomElement &element ) con
     }
 }
 
+ItemModelBase *TreeViewBase::itemModel() const
+{
+    QAbstractItemModel *m = model();
+    QAbstractProxyModel *p = qobject_cast<QAbstractProxyModel*>( m );
+    while ( p ) {
+        m = p->sourceModel();
+        p = qobject_cast<QAbstractProxyModel*>( m );
+    }
+    return qobject_cast<ItemModelBase*>( m );
+}
+
 //----------------------
 DoubleTreeViewPrintingDialog::DoubleTreeViewPrintingDialog( ViewBase *view, DoubleTreeViewBase *treeview, Project *project )
     : PrintingDialog( view ),
@@ -1267,7 +1398,7 @@ int DoubleTreeViewPrintingDialog::documentLastPage() const
 
 int DoubleTreeViewPrintingDialog::firstRow( int page ) const
 {
-    kDebug()<<page;
+    kDebug(planDbg())<<page;
     int pageNumber = page - documentFirstPage();
     QHeaderView *mh = m_tree->masterView()->header();
     QHeaderView *sh = m_tree->slaveView()->header();
@@ -1299,7 +1430,7 @@ int DoubleTreeViewPrintingDialog::firstRow( int page ) const
         row = 0;
         while ( idx.isValid() ) {
             if ( row >= rowsPrPage * pageNumber ) {
-                kDebug()<<page<<pageNumber;
+                kDebug(planDbg())<<page<<pageNumber;
                 break;
             }
             ++row;
@@ -1309,7 +1440,7 @@ int DoubleTreeViewPrintingDialog::firstRow( int page ) const
             row = -1;
         }
     }
-    kDebug()<<row<<rowsPrPage;
+    kDebug(planDbg())<<row<<rowsPrPage;
     return row;
 }
 
@@ -1339,7 +1470,7 @@ void DoubleTreeViewPrintingDialog::printPage( int page, QPainter &painter )
 
     QAbstractItemModel *model = m_tree->model();
     Q_ASSERT( model != 0 );
-    kDebug()<<pageRect<<paperRect;
+    kDebug(planDbg())<<pageRect<<paperRect;
 
     painter.translate( pageRect.topLeft() );
 
@@ -1383,17 +1514,17 @@ void DoubleTreeViewPrintingDialog::printPage( int page, QPainter &painter )
             painter.drawRect( r );
             painter.drawText( r, align, text );
         }
-        //kDebug()<<text<<"hidden="<<h->isSectionHidden( i )<<h->sectionPosition( i );
+        //kDebug(planDbg())<<text<<"hidden="<<h->isSectionHidden( i )<<h->sectionPosition( i );
     }
     if ( m_firstRow == -1 ) {
-        kDebug()<<"No data";
+        kDebug(planDbg())<<"No data";
         painter.restore();
         return;
     }
     painter.setBrush( QBrush() );
     QModelIndex idx = model->index( m_firstRow, 0, QModelIndex() );
     int numRows = 0;
-    //kDebug()<<page<<rowsPrPage;
+    //kDebug(planDbg())<<page<<rowsPrPage;
     while ( idx.isValid() && numRows < rowsPrPage ) {
         painter.translate( 0, height );
         h += height;
@@ -1466,7 +1597,7 @@ void DoubleTreeViewBase::expandAll()
 
 void DoubleTreeViewBase::setParentsExpanded( const QModelIndex &idx, bool expanded )
 {
-    //kDebug()<<idx<<m_leftview->isExpanded( idx )<<m_rightview->isExpanded( idx );
+    //kDebug(planDbg())<<idx<<m_leftview->isExpanded( idx )<<m_rightview->isExpanded( idx );
     QModelIndex p = model()->parent( idx );
     QList<QModelIndex> lst;
     while ( p.isValid() ) {
@@ -1477,7 +1608,7 @@ void DoubleTreeViewBase::setParentsExpanded( const QModelIndex &idx, bool expand
         p = lst.takeLast();
         m_leftview->setExpanded( p, expanded );
         m_rightview->setExpanded( m_rightview->firstVisibleIndex( p ), expanded ); //HACK: qt can't handle that column 0 is hidden!
-        //kDebug()<<p<<m_leftview->isExpanded( p )<<m_rightview->isExpanded( p );
+        //kDebug(planDbg())<<p<<m_leftview->isExpanded( p )<<m_rightview->isExpanded( p );
     }
 }
 
@@ -1528,15 +1659,29 @@ void DoubleTreeViewBase::init()
     connect( m_rightview->header(), SIGNAL( sortIndicatorChanged( int, Qt::SortOrder ) ), SLOT( slotRightSortIndicatorChanged( int, Qt::SortOrder ) ) );
 }
 
-void DoubleTreeViewBase::slotLeftSortIndicatorChanged( int /*logicalIndex*/, Qt::SortOrder /*order*/ )
+void DoubleTreeViewBase::slotLeftSortIndicatorChanged( int logicalIndex, Qt::SortOrder /*order*/ )
 {
+    QSortFilterProxyModel *sf = qobject_cast<QSortFilterProxyModel*>( model() );
+    if ( sf ) {
+        ItemModelBase *m = m_rightview->itemModel();
+        if ( m ) {
+            sf->setSortRole( m->sortRole( logicalIndex ) );
+        }
+    }
     m_leftview->header()->setSortIndicatorShown( true );
     // sorting controlled by left treeview, turn right off
     m_rightview->header()->setSortIndicatorShown( false );
 }
 
-void DoubleTreeViewBase::slotRightSortIndicatorChanged( int /*logicalIndex*/, Qt::SortOrder /*order*/ )
+void DoubleTreeViewBase::slotRightSortIndicatorChanged( int logicalIndex, Qt::SortOrder /*order*/ )
 {
+    QSortFilterProxyModel *sf = qobject_cast<QSortFilterProxyModel*>( model() );
+    if ( sf ) {
+        ItemModelBase *m = m_rightview->itemModel();
+        if ( m ) {
+            sf->setSortRole( m->sortRole( logicalIndex ) );
+        }
+    }
     m_rightview->header()->setSortIndicatorShown( true );
     // sorting controlled by right treeview, turn left off
     m_leftview->header()->setSortIndicatorShown( false );
@@ -1574,12 +1719,12 @@ void DoubleTreeViewBase::hideColumns( const QList<int> &masterList, const QList<
         QList<int> lst;
         for ( int c = 0; c < model()->columnCount(); ++c ) {
             // only hide columns hidden in *both* views
-            //kDebug()<<c<<(mlst.indexOf( c ))<<(slst.indexOf( c ));
+            //kDebug(planDbg())<<c<<(mlst.indexOf( c ))<<(slst.indexOf( c ));
             if ( (mlst.indexOf( c ) >= 0) && (slst.indexOf( c ) >= 0) ) {
                 lst << c;
             }
         }
-        //kDebug()<<lst;
+        //kDebug(planDbg())<<lst;
         m_leftview->setColumnsHidden( lst );
     } else {
         setStretchFactors();
@@ -1588,7 +1733,7 @@ void DoubleTreeViewBase::hideColumns( const QList<int> &masterList, const QList<
 
 void DoubleTreeViewBase::slotToRightView( const QModelIndex &index )
 {
-    //kDebug()<<index.column();
+    //kDebug(planDbg())<<index.column();
     QModelIndex nxt = m_rightview->firstColumn( index.row(), model()->parent( index ) );
     m_rightview->setFocus();
     if ( nxt.isValid() ) {
@@ -1598,7 +1743,7 @@ void DoubleTreeViewBase::slotToRightView( const QModelIndex &index )
 
 void DoubleTreeViewBase::slotToLeftView( const QModelIndex &index )
 {
-    //kDebug()<<index.column();
+    //kDebug(planDbg())<<index.column();
     QModelIndex prv = m_leftview->lastColumn( index.row(), model()->parent( index ) );
     m_leftview->setFocus();
     if ( prv.isValid() ) {
@@ -1608,7 +1753,7 @@ void DoubleTreeViewBase::slotToLeftView( const QModelIndex &index )
 
 void DoubleTreeViewBase::slotEditToRightView( const QModelIndex &index )
 {
-    //kDebug()<<index.column()<<endl;
+    //kDebug(planDbg())<<index.column()<<endl;
     if ( m_rightview->isHidden() ) {
         return;
     }
@@ -1624,7 +1769,7 @@ void DoubleTreeViewBase::slotEditToRightView( const QModelIndex &index )
 
 void DoubleTreeViewBase::slotEditToLeftView( const QModelIndex &index )
 {
-    //kDebug()<<index.column()<<endl;
+    //kDebug(planDbg())<<index.column()<<endl;
     if ( m_leftview->isHidden() ) {
         return;
     }
@@ -1646,6 +1791,12 @@ void DoubleTreeViewBase::setReadWrite( bool rw )
     m_rightview->setReadWrite( rw );
 }
 
+void DoubleTreeViewBase::closePersistentEditor( const QModelIndex &index )
+{
+    m_leftview->closePersistentEditor( index );
+    m_rightview->closePersistentEditor( index );
+}
+
 void DoubleTreeViewBase::setModel( QAbstractItemModel *model )
 {
     m_leftview->setModel( model );
@@ -1765,14 +1916,14 @@ void DoubleTreeViewBase::setDefaultDropAction( Qt::DropAction action )
 
 void DoubleTreeViewBase::slotRightHeaderContextMenuRequested( const QPoint &pos )
 {
-    //kDebug();
+    //kDebug(planDbg());
     emit slaveHeaderContextMenuRequested( pos );
     emit headerContextMenuRequested( pos );
 }
 
 void DoubleTreeViewBase::slotLeftHeaderContextMenuRequested( const QPoint &pos )
 {
-    //kDebug();
+    //kDebug(planDbg());
     emit masterHeaderContextMenuRequested( pos );
     emit headerContextMenuRequested( pos );
 }
@@ -1782,33 +1933,33 @@ void DoubleTreeViewBase::setStretchFactors()
     int lc = m_leftview->header()->count() - m_leftview->header()->hiddenSectionCount();
     int rc = m_rightview->header()->count() - m_rightview->header()->hiddenSectionCount();
     setStretchFactor( indexOf( m_rightview ), qMax( 1, qMin( 4, rc / qMax( 1, lc ) ) ) );
-    //kDebug()<<this<<"set stretch factor="<<qMax( 1, qMin( 4, rc / lc ) );
+    //kDebug(planDbg())<<this<<"set stretch factor="<<qMax( 1, qMin( 4, rc / lc ) );
 }
 
 bool DoubleTreeViewBase::loadContext( const QMetaEnum &map, const KoXmlElement &element )
 {
-    //kDebug();
+    //kDebug(planDbg());
     QList<int> lst1;
     QList<int> lst2;
-    KoXmlElement e = element.namedItem( "master" ).toElement();
+    KoXmlElement e = element.namedItem( "slave" ).toElement();
     if ( ! e.isNull() ) {
-        m_leftview->loadContext( map, e );
-    }
-    e = element.namedItem( "slave" ).toElement();
-    if ( ! e.isNull() ) {
-        m_rightview->loadContext( map, e );
         if ( e.attribute( "hidden", "false" ) == "true" ) {
             setViewSplitMode( false );
         } else {
             setStretchFactors();
         }
+        m_rightview->loadContext( map, e );
+    }
+    e = element.namedItem( "master" ).toElement();
+    if ( ! e.isNull() ) {
+        m_leftview->loadContext( map, e );
     }
     return true;
 }
 
 void DoubleTreeViewBase::saveContext( const QMetaEnum &map, QDomElement &element ) const
 {
-    //kDebug()<<objectName();
+    //kDebug(planDbg())<<objectName();
     QDomElement e = element.ownerDocument().createElement( "master" );
     element.appendChild( e );
     m_leftview->saveContext( map, e );
