@@ -17,7 +17,7 @@
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
-*/
+ */
 
 
 // Own
@@ -48,14 +48,14 @@ using namespace KChart;
 class Parser
 {
 public:
-    Parser( const QString & input )
-        : m_input( input )
-        , m_pos( m_input.constEnd() )
+    Parser(const QString & input)
+        : m_input(input)
+        , m_pos(m_input.constEnd())
     {
-        m_delimiter.append( QChar::fromLatin1( '.' ) );
-        m_delimiter.append( QChar::fromLatin1( ':' ) );
-        m_delimiter.append( QChar::fromLatin1( ';' ) );
-        m_delimiter.append( QChar::fromLatin1( ' ' ) );
+        m_delimiter.append(QChar::fromLatin1('.'));
+        m_delimiter.append(QChar::fromLatin1(':'));
+        m_delimiter.append(QChar::fromLatin1(';'));
+        m_delimiter.append(QChar::fromLatin1(' '));
     }
     bool parse();
     QList< QRect > getResult() const { return m_result; }
@@ -65,8 +65,8 @@ private:
     struct Token
     {
         enum TokenType{ Dot = 0, DoubleDot = 1, Space = 2, Spacer = 3, Identifier = 4, End };
-        Token( TokenType type, const QString & identifier ): m_type( type ), m_identifier( identifier ){}
-        Token(): m_type( End ) {}
+        Token(TokenType type, const QString & identifier): m_type(type), m_identifier(identifier){}
+        Token(): m_type(End) {}
         TokenType m_type;
         QString m_identifier;
     };
@@ -79,7 +79,7 @@ private:
     inline bool parseName2();
     inline bool parsePoint();
     inline bool parseRegion2();
-    inline void setTableName( const QString &name );
+    inline void setTableName(const QString &name);
 
 private:
     const QString m_input;
@@ -93,15 +93,15 @@ private:
     QVector< QChar > m_delimiter;
 };
 
-void Parser::setTableName( const QString &name )
+void Parser::setTableName(const QString &name)
 {
     QString strippedName = name;
-    if ( name.startsWith( QChar::fromLatin1( '$' ) ) )
-        strippedName.remove( 0, 1 );
-    if ( m_tableName.isEmpty() )        
+    if (name.startsWith(QChar::fromLatin1('$')))
+        strippedName.remove(0, 1);
+    if (m_tableName.isEmpty())        
         m_tableName = strippedName;
     else
-        if ( strippedName != m_tableName )
+        if (strippedName != m_tableName)
             kDebug() << "More than one sheet referenced, this is currently not supported";
 }
 
@@ -117,18 +117,16 @@ bool Parser::parse()
 Parser::Token Parser::parseToken()
 {
     Token::TokenType type = Token::End;
-    if ( m_pos != m_input.constEnd() )
-    {
-        switch( m_delimiter.indexOf( *m_pos ) )
-        {
-        case( 0 ):
+    if (m_pos != m_input.constEnd()) {
+        switch(m_delimiter.indexOf(*m_pos)) {
+        case(0):
             type = Token::Dot;
             break;
-        case( 1 ):
+        case(1):
             type = Token::DoubleDot;
             break;
-        case( 2 ):
-        case( 3 ):
+        case(2):
+        case(3):
             type = Token::Space;
             break;
         default:
@@ -136,61 +134,54 @@ Parser::Token Parser::parseToken()
         }
     }
     bool dollarPrefix = false;
-    if ( m_index >= m_input.size() )
+    if (m_index >= m_input.size())
         type = Token::End;
-    else if ( *m_pos == QChar::fromLatin1( '$' ) )
-    {
+    else if (*m_pos == QChar::fromLatin1('$')) {
         ++m_pos;
         ++m_index;
     }
     QString identifier;
-    if ( m_pos != m_input.constEnd() && *m_pos == QChar::fromLatin1( '\'' ) )
-    {
+    if (m_pos != m_input.constEnd() && *m_pos == QChar::fromLatin1('\'')) {
         ++m_pos;
         ++m_index;
         int startPos = m_index;
-        for ( ; m_pos != m_input.constEnd() && *m_pos != QChar::fromLatin1( '\'' ); ++m_pos, ++m_index )
+        for (; m_pos != m_input.constEnd() && *m_pos != QChar::fromLatin1('\''); ++m_pos, ++m_index)
             ;
 
-        if ( type == Token::Identifier )
-            identifier = m_input.mid( startPos, m_index - startPos );
-        if ( m_pos != m_input.constEnd() )
-        {
+        if (type == Token::Identifier)
+            identifier = m_input.mid(startPos, m_index - startPos);
+        if (m_pos != m_input.constEnd()) {
             ++m_pos;
             ++m_index;
         }
     }
-    else
-    {
+    else {
         int startPos = m_index;
-        for ( ; m_pos != m_input.constEnd() && !m_delimiter.contains( *m_pos ); ++m_pos, ++m_index )
+        for (; m_pos != m_input.constEnd() && !m_delimiter.contains(*m_pos); ++m_pos, ++m_index)
             ;
-        if ( m_pos != m_input.constEnd() && startPos == m_index )
-        {
+        if (m_pos != m_input.constEnd() && startPos == m_index) {
             ++m_index;
             ++m_pos;
         }
-        if ( type == Token::Identifier )
-            identifier = m_input.mid( startPos, m_index - startPos );
+        if (type == Token::Identifier)
+            identifier = m_input.mid(startPos, m_index - startPos);
     }
 
-    return Token( type, identifier );
+    return Token(type, identifier);
 }
 
 void Parser::eatWhitespaces()
 {
-    for ( ; m_pos != m_input.constEnd() && *m_pos == QChar::fromLatin1( ' ' ); ++m_pos, ++m_index )
+    for (; m_pos != m_input.constEnd() && *m_pos == QChar::fromLatin1(' '); ++m_pos, ++m_index)
         ;
 }
 
 bool Parser::parseRegionList()
 {
     bool res = true;
-    for ( ; m_currentToken.m_type != Token::End; m_currentToken = parseToken() )
-    {
-        if ( m_currentToken.m_type != Token::Space )
-        {
-            if ( m_currentToken.m_type == Token::Identifier )
+    for (; m_currentToken.m_type != Token::End; m_currentToken = parseToken()) {
+        if (m_currentToken.m_type != Token::Space) {
+            if (m_currentToken.m_type == Token::Identifier)
                 res = parseRegion();
             else
                 res = false;
@@ -206,24 +197,22 @@ bool Parser::parseRegion()
     res &= parseRegion2();
     m_currentToken = parseToken();
     //qDebug() << "CurrentToken " << m_currentToken.m_identifier << m_currentToken.m_type;
-    if ( m_currentToken.m_type == Token::DoubleDot )
-    {
+    if (m_currentToken.m_type == Token::DoubleDot) {
         const QPoint topLeft = m_currentPoint;
         m_currentToken = parseToken();
         res &= parseRegion2();
         //m_currentToken = parseToken();
-        m_result.append( QRect( topLeft, m_currentPoint )  );
+        m_result.append(QRect(topLeft, m_currentPoint));
         //qDebug() << "DoubleDot";
     }
-    else
-    {
-        m_result.append( QRect( m_currentPoint, m_currentPoint ) );
+    else {
+        m_result.append(QRect(m_currentPoint, m_currentPoint));
         //qDebug() << "NODoubleDot";
     }
     
-    if ( m_currentToken.m_type == Token::Space )
+    if (m_currentToken.m_type == Token::Space)
         res &= parseRegionList();
-    else if ( m_currentToken.m_type == Token::End )
+    else if (m_currentToken.m_type == Token::End)
         return res;
     else
         res = false;
@@ -236,32 +225,32 @@ bool Parser::parseRegion2()
     //qDebug() << "ParseRegion2";
     bool res = true;
 
-    if ( m_currentToken.m_type != Token::Identifier && m_currentToken.m_type != Token::Dot )
+    if (m_currentToken.m_type != Token::Identifier && m_currentToken.m_type != Token::Dot)
         res = false;
 
     const QString firstIdentifier = m_currentToken.m_type != Token::Dot ? m_currentToken.m_identifier : tableName();
-    if ( m_currentToken.m_type != Token::Dot )
+    if (m_currentToken.m_type != Token::Dot)
         m_currentToken = parseToken();
-    if ( m_currentToken.m_type == Token::Dot )
+    if (m_currentToken.m_type == Token::Dot)
     {
         m_currentToken = parseToken();
-        if ( m_currentToken.m_type == Token::Identifier )
+        if (m_currentToken.m_type == Token::Identifier)
         {            
-            QRegExp regEx( QString::fromLatin1( "([$]*)([A-Z]+)([$]*)([0-9]+)" ) );
-            regEx.exactMatch( m_currentToken.m_identifier );
-            m_currentPoint = QPoint( CellRegion::rangeStringToInt( regEx.cap( 2 ) ), regEx.cap( 4 ).toInt() );
-            //qDebug() << "FUN" << regEx.cap( 2 ) << " " << regEx.cap( 4 );
-            setTableName( firstIdentifier );
+            QRegExp regEx(QString::fromLatin1("([$]*)([A-Z]+)([$]*)([0-9]+)"));
+            regEx.exactMatch(m_currentToken.m_identifier);
+            m_currentPoint = QPoint(CellRegion::rangeStringToInt(regEx.cap(2)), regEx.cap(4).toInt());
+            //qDebug() << "FUN" << regEx.cap(2) << " " << regEx.cap(4);
+            setTableName(firstIdentifier);
         }
         else
             res = false;
     }
     else
     {
-        QRegExp regEx( QString::fromLatin1( "([$]*)([A-Z]+)([$]*)([0-9]+)" ) );
-        regEx.exactMatch( firstIdentifier );
-        //qDebug() << "FUN" << regEx.cap( 2 ) << " " << regEx.cap( 4 );
-        m_currentPoint = QPoint( CellRegion::rangeStringToInt( regEx.cap( 2 ) ), regEx.cap( 4 ).toInt() );
+        QRegExp regEx(QString::fromLatin1("([$]*)([A-Z]+)([$]*)([0-9]+)"));
+        regEx.exactMatch(firstIdentifier);
+        //qDebug() << "FUN" << regEx.cap(2) << " " << regEx.cap(4);
+        m_currentPoint = QPoint(CellRegion::rangeStringToInt(regEx.cap(2)), regEx.cap(4).toInt());
     }
     //qDebug() << "TableName "<< m_tableName;
     //qDebug() << firstIdentifier;
@@ -277,51 +266,51 @@ bool Parser::parseRegion2()
 // {
 //     bool res = true;
 //     int startIndex = m_index;
-//     while( m_pos != m_input.end() && *m_pos != QChar::fromLatin1( ':' ) )
+//     while(m_pos != m_input.end() && *m_pos != QChar::fromLatin1(':'))
 //     {
 //         ++m_pos;
 //         ++m_index;
 //     }
-//     const QString currentString = m_input.mid( startIndex, m_index - startIndex );
+//     const QString currentString = m_input.mid(startIndex, m_index - startIndex);
 //     qDebug() << "PointString" << currentString;
-//     QRegExp regEx( QString::fromLatin1( "[A-Z]+[0-9]+" ) );
-//     regEx.indexIn( currentString );
-//     m_currentPoint = QPoint( CellRegion::rangeStringToInt( regEx.cap(0) ), regEx.cap(1).toInt() );
+//     QRegExp regEx(QString::fromLatin1("[A-Z]+[0-9]+"));
+//     regEx.indexIn(currentString);
+//     m_currentPoint = QPoint(CellRegion::rangeStringToInt(regEx.cap(0)), regEx.cap(1).toInt());
 //     return res;
 // }
 /************************ENDRegionParser*******************************/
 
-static QString columnName( uint column );
-//static int rangeCharToInt( char c );
+static QString columnName(uint column);
+//static int rangeCharToInt(char c);
 
 /**
  * Makes sure that quotes are added if name contains spaces or special
  * characters. May also be used to escape certain characters if needed.
  */
-static QString formatTableName( QString name )
+static QString formatTableName(QString name)
 {
     static const QList<QChar> specialChars =
         QList<QChar>() << ' ' << '\t' << '-' << '\'';
 
     bool containsSpecialChars = false;
-    foreach( QChar c, specialChars )
-        containsSpecialChars = containsSpecialChars || name.contains( c );
+    foreach(QChar c, specialChars)
+        containsSpecialChars = containsSpecialChars || name.contains(c);
 
-    if( containsSpecialChars )
-        name.prepend( '\'' ).append( '\'' );
+    if(containsSpecialChars)
+        name.prepend('\'').append('\'');
 
     return name;
 }
 
 /**
  * Reverts any operation done by formatTableName(), so that ideally
- * unformatTableName( formatTableName( name ) ) == name
+ * unformatTableName(formatTableName(name)) == name
  */
-static QString unformatTableName( QString name )
+static QString unformatTableName(QString name)
 {
-    if ( name.startsWith( '\'' ) && name.endsWith( '\'' ) ) {
-        name.remove( 0, 1 );
-        name.remove( name.length() - 1, 1 );
+    if (name.startsWith('\'') && name.endsWith('\'')) {
+        name.remove(0, 1);
+        name.remove(name.length() - 1, 1);
     }
 
     return name;
@@ -333,7 +322,7 @@ public:
     Private();
     ~Private();
 
-    QString pointToString( const QPoint &point ) const;
+    QString pointToString(const QPoint &point) const;
 
     // These are actually one-dimensional, but can have different
     // orientations (hor / vert).
@@ -362,93 +351,93 @@ CellRegion::Private::~Private()
 
 
 CellRegion::CellRegion()
-    : d( new Private() )
+    : d(new Private())
 {
 }
 
-CellRegion::CellRegion( const CellRegion &region )
-    : d( new Private() )
+CellRegion::CellRegion(const CellRegion &region)
+    : d(new Private())
 {
     // Use operator=();
     *this = region;
 }
 
-CellRegion::CellRegion( TableSource *source, const QString& regions )
-    : d( new Private() )
+CellRegion::CellRegion(TableSource *source, const QString& regions)
+    : d(new Private())
 {
     // A dollar sign before a part of the address means that this part
     // is absolute. This is irrelevant for us, however, thus we can remove
     // all occurences of '$', and handle relative and absolute addresses in
     // the same way.
     // See ODF specs $8.3.1 "Referencing Table Cells"
-    Parser parser( regions );
+    Parser parser(regions);
     const bool success = parser.parse();
-    if ( !success )
+    if (!success)
         kDebug() << "Parsing cell region failed";
     d->rects = parser.getResult().toVector();
-    d->table = source->get( parser.tableName() );
-//     QStringList regionsList = regions.split( " ", QString::SkipEmptyParts );
-//     Q_FOREACH( const QString& region, regionsList ) {
-//       QString searchStr = QString( region ).remove( "$" );
+    d->table = source->get(parser.tableName());
+//     QStringList regionsList = regions.split(" ", QString::SkipEmptyParts);
+//     Q_FOREACH(const QString& region, regionsList) {
+//       QString searchStr = QString(region).remove("$");
 //       QRegExp regEx;
 // 
-//       QStringList regionList = searchStr.split( ";" );
-//       Q_FOREACH( const QString &region, regionList ) {
-//           const bool isPoint = !region.contains( ':' );
-//           if ( isPoint )
-//               regEx = QRegExp( "(|.*\\.)([A-Z]+)([0-9]+)" );
+//       QStringList regionList = searchStr.split(";");
+//       Q_FOREACH(const QString &region, regionList) {
+//           const bool isPoint = !region.contains(':');
+//           if (isPoint)
+//               regEx = QRegExp("(|.*\\.)([A-Z]+)([0-9]+)");
 //           else // support range-notations like Sheet1.D2:Sheet1.F2 Sheet1.D2:F2 D2:F2
-//               regEx = QRegExp ( "(|.*\\.)([A-Z]+)([0-9]+)\\:(|.*\\.)([A-Z]+)([0-9]+)" );
+//               regEx = QRegExp ("(|.*\\.)([A-Z]+)([0-9]+)\\:(|.*\\.)([A-Z]+)([0-9]+)");
 // 
 //           // Check if region string is valid (e.g. not empty)
-//           if ( regEx.indexIn( region ) >= 0 ) {
+//           if (regEx.indexIn(region) >= 0) {
 //               // It is possible for a cell-range-address as defined in ODF to contain
 //               // refernces to cells of more than one sheet. This, however, we ignore
 //               // here. We do not support more than one table in a cell region.
 //               // Also we do not support regions spanned over different sheets. For us
 //               // everything is either on no sheet or on the same sheet.
-//               QString sheetName = regEx.cap( 1 );
-//               if ( sheetName.endsWith( "." ) )
-//                   sheetName = sheetName.left( sheetName.length() - 1 );
+//               QString sheetName = regEx.cap(1);
+//               if (sheetName.endsWith("."))
+//                   sheetName = sheetName.left(sheetName.length() - 1);
 //               // TODO: Support for multiple tables in one region
-//               d->table = source->get( unformatTableName( sheetName ) );
+//               d->table = source->get(unformatTableName(sheetName));
 // 
-//               QPoint topLeft( rangeStringToInt( regEx.cap(2) ), regEx.cap(3).toInt() );
-//               if ( isPoint ) {
-//                   d->rects.append( QRect( topLeft, QSize( 1, 1 ) ) );
+//               QPoint topLeft(rangeStringToInt(regEx.cap(2)), regEx.cap(3).toInt());
+//               if (isPoint) {
+//                   d->rects.append(QRect(topLeft, QSize(1, 1)));
 //               } else {
-//                   QPoint bottomRight( rangeStringToInt( regEx.cap(5) ), regEx.cap(6).toInt() );
-//                   d->rects.append( QRect( topLeft, bottomRight ) );
+//                   QPoint bottomRight(rangeStringToInt(regEx.cap(5)), regEx.cap(6).toInt());
+//                   d->rects.append(QRect(topLeft, bottomRight));
 //               }
 //           }
 //       }
 //     }
 }
 
-CellRegion::CellRegion( Table *table, const QPoint &point )
-    : d( new Private() )
+CellRegion::CellRegion(Table *table, const QPoint &point)
+    : d(new Private())
 {
     d->table = table;
-    add( point );
+    add(point);
 }
 
-CellRegion::CellRegion( Table *table, const QRect &rect )
-    : d( new Private() )
+CellRegion::CellRegion(Table *table, const QRect &rect)
+    : d(new Private())
 {
     d->table = table;
-    add( rect );
+    add(rect);
 }
 
-CellRegion::CellRegion( Table *table, const QVector<QRect> &rects )
-    : d( new Private() )
+CellRegion::CellRegion(Table *table, const QVector<QRect> &rects)
+    : d(new Private())
 {
     d->table = table;
-    foreach( const QRect& rect, rects )
-        add( rect );
+    foreach(const QRect& rect, rects)
+        add(rect);
 }
 
-CellRegion::CellRegion( Table *table )
-    : d( new Private() )
+CellRegion::CellRegion(Table *table)
+    : d(new Private())
 {
     d->table = table;
 }
@@ -459,16 +448,16 @@ CellRegion::~CellRegion()
 }
 
 
-CellRegion& CellRegion::operator = ( const CellRegion& region )
+CellRegion& CellRegion::operator = (const CellRegion& region)
 {
     d->rects        = region.d->rects;
     d->boundingRect = region.d->boundingRect;
-    d->table = region.d->table;
+    d->table        = region.d->table;
 
     return *this;
 }
 
-bool CellRegion::operator == ( const CellRegion &other ) const
+bool CellRegion::operator == (const CellRegion &other) const
 {
     return d->rects == other.d->rects;
 }
@@ -499,74 +488,74 @@ bool CellRegion::isValid() const
     return d->rects.size() > 0 && d->table ;
 }
 
-QString CellRegion::Private::pointToString( const QPoint &point ) const
+QString CellRegion::Private::pointToString(const QPoint &point) const
 {
     QString result;
 
-    result.append( '$' + columnName( point.x() ) );
-    result.append( '$' + QString::number( point.y() ) );
+    result.append('$' + columnName(point.x()));
+    result.append('$' + QString::number(point.y()));
 
     return result;
 }
 
 QString CellRegion::toString() const
 {
-    if ( !isValid() )
+    if (!isValid())
         return QString();
 
     QString result;
-    for ( int i = 0; i < d->rects.count(); ++i ) {
+    for (int i = 0; i < d->rects.count(); ++i) {
         const QRect range = d->rects[i];
         // Top-left corner
-        if ( table() )
-            result.append( '$' + formatTableName( table()->name() ) + '.' );
-        result.append( d->pointToString( range.topLeft() ) );
+        if (table())
+            result.append('$' + formatTableName(table()->name()) + '.');
+        result.append(d->pointToString(range.topLeft()));
 
         // If it is not a point, append rect's bottom-right corner
-        if ( range.topLeft() != range.bottomRight() ) {
-            result.append( ':' );
-            result.append( d->pointToString( range.bottomRight() ) );
+        if (range.topLeft() != range.bottomRight()) {
+            result.append(':');
+            result.append(d->pointToString(range.bottomRight()));
         }
 
         // Separate ranges by a comma, except for the last one
-        if ( i < d->rects.count() - 1 )
-            result.append( ';' );
+        if (i < d->rects.count() - 1)
+            result.append(';');
     }
     return result;
 }
 
 
-bool CellRegion::contains( const QPoint &point, bool proper ) const
+bool CellRegion::contains(const QPoint &point, bool proper) const
 {
-    foreach ( const QRect &rect, d->rects ) {
-        if ( rect.contains( point, proper ) )
+    foreach (const QRect &rect, d->rects) {
+        if (rect.contains(point, proper))
             return true;
     }
 
     return false;
 }
 
-bool CellRegion::contains( const QRect &rect, bool proper ) const
+bool CellRegion::contains(const QRect &rect, bool proper) const
 {
-    foreach ( const QRect &r, d->rects ) {
-        if ( r.contains( rect, proper ) )
+    foreach (const QRect &r, d->rects) {
+        if (r.contains(rect, proper))
             return true;
     }
 
     return false;
 }
 
-bool CellRegion::intersects( const CellRegion &other ) const
+bool CellRegion::intersects(const CellRegion &other) const
 {
     // If both regions lie within only one table and these tables
     // are different, they trivially do not intersect.
-    if ( table() && other.table() &&
-         table() != other.table() )
+    if (table() && other.table() &&
+         table() != other.table())
         return false;
 
-    foreach ( const QRect &r, d->rects ) {
-        foreach( const QRect &_r, other.d->rects ) {
-            if ( r.intersects( _r ) )
+    foreach (const QRect &r, d->rects) {
+        foreach(const QRect &_r, other.d->rects) {
+            if (r.intersects(_r))
                 return true;
         }
     }
@@ -574,13 +563,13 @@ bool CellRegion::intersects( const CellRegion &other ) const
     return false;
 }
 
-CellRegion CellRegion::intersected( const QRect &rect ) const
+CellRegion CellRegion::intersected(const QRect &rect) const
 {
     CellRegion intersections;
 
-    foreach ( const QRect &r, d->rects ) {
-        if ( r.intersects( rect ) )
-            intersections.add( r.intersected( rect ) );
+    foreach (const QRect &r, d->rects) {
+        if (r.intersects(rect))
+            intersections.add(r.intersected(rect));
     }
 
     return intersections;
@@ -588,10 +577,10 @@ CellRegion CellRegion::intersected( const QRect &rect ) const
 
 Qt::Orientation CellRegion::orientation() const
 {
-    foreach ( const QRect &rect, d->rects ) {
-        if ( rect.width() > 1 )
+    foreach (const QRect &rect, d->rects) {
+        if (rect.width() > 1)
                 return Qt::Horizontal;
-        if ( rect.height() > 1 )
+        if (rect.height() > 1)
                 return Qt::Vertical;
     }
 
@@ -610,56 +599,56 @@ int CellRegion::cellCount() const
      * the CellRegion to proper handle multi-dimension
      * ranges too).
      *
-    foreach ( const QRect &rect, d->rects )
-        count += ( rect.width() * rect.height() );
+    foreach (const QRect &rect, d->rects)
+        count += (rect.width() * rect.height());
     */
 
-    if ( orientation() == Qt::Horizontal ) {
-        foreach ( const QRect &rect, d->rects )
+    if (orientation() == Qt::Horizontal) {
+        foreach (const QRect &rect, d->rects)
             count += rect.width();
     }
     else {
-        foreach( const QRect &rect, d->rects )
+        foreach(const QRect &rect, d->rects)
             count += rect.height();
     }
     return count;
 }
 
-void CellRegion::add( const CellRegion &other )
+void CellRegion::add(const CellRegion &other)
 {
-    add( other.rects() );
+    add(other.rects());
 }
 
-void CellRegion::add( const QPoint &point )
+void CellRegion::add(const QPoint &point)
 {
-    add( QRect( point, QSize( 1, 1 ) ) );
+    add(QRect(point, QSize(1, 1)));
 }
 
-void CellRegion::add( const QRect &rect )
+void CellRegion::add(const QRect &rect)
 {
 // These checks are obsolete, a CellRegion can be used otherwise as well
 #if 0
-    if ( !rect.isValid() ) {
+    if (!rect.isValid()) {
         qWarning() << "CellRegion::add() Attempt to add invalid rectangle";
         qWarning() << "CellRegion::add():" << rect;
         return;
     }
 
-    if ( rect.width() > 1 && rect.height() > 1 ) {
+    if (rect.width() > 1 && rect.height() > 1) {
         qWarning() << "CellRegion::add() Attempt to add rectangle with height AND width > 1";
         qWarning() << "CellRegion::add():" << rect;
         return;
     }
 #endif
 
-    d->rects.append( rect );
+    d->rects.append(rect);
     d->boundingRect |= rect;
 }
 
-void CellRegion::add( const QVector<QRect> &rects )
+void CellRegion::add(const QVector<QRect> &rects)
 {
-    foreach ( const QRect &rect, rects )
-        add( rect );
+    foreach (const QRect &rect, rects)
+        add(rect);
 }
 
 QRect CellRegion::boundingRect() const
@@ -667,25 +656,25 @@ QRect CellRegion::boundingRect() const
     return d->boundingRect;
 }
 
-bool CellRegion::hasPointAtIndex( int index ) const
+bool CellRegion::hasPointAtIndex(int index) const
 {
-    return pointAtIndex( index ) != QPoint( -1, -1 );
+    return pointAtIndex(index) != QPoint(-1, -1);
 }
 
-QPoint CellRegion::pointAtIndex( int index ) const
+QPoint CellRegion::pointAtIndex(int index) const
 {
     // sum of all previous rectangle indices
     int i = 0;
 
-    foreach ( const QRect &rect, d->rects ) {
+    foreach (const QRect &rect, d->rects) {
         // Rectangle is horizontal
-        if ( rect.width() > 1 ) {
+        if (rect.width() > 1) {
             // Found it!
             // Index refers to point in current rectangle
-            if ( i + rect.width() > index ) {
+            if (i + rect.width() > index) {
                 // Local index of point in this rectangle
                 int j = index - i;
-                return QPoint( rect.x() + j, rect.y() );
+                return QPoint(rect.x() + j, rect.y());
             }
 
             // add number of indices in current rectangle to total index count
@@ -694,10 +683,10 @@ QPoint CellRegion::pointAtIndex( int index ) const
         else {
             // Found it!
             // Index refers to point in current rectangle
-            if ( i + rect.height() > index ) {
+            if (i + rect.height() > index) {
                 // Local index of point in this rectangle
                 int j = index - i;
-                return QPoint( rect.x(), rect.y() + j );
+                return QPoint(rect.x(), rect.y() + j);
             }
 
             // add number of indices in current rectangle to total index count
@@ -706,22 +695,22 @@ QPoint CellRegion::pointAtIndex( int index ) const
     }
 
     // Invalid index!
-    return QPoint( -1, -1 );
+    return QPoint(-1, -1);
 }
 
-int CellRegion::indexAtPoint( const QPoint &point ) const
+int CellRegion::indexAtPoint(const QPoint &point) const
 {
     int indicesLeftToPoint = 0;
     bool found = false;
 
-    foreach ( const QRect &rect, d->rects ) {
-        if ( !rect.contains( point ) ) {
+    foreach (const QRect &rect, d->rects) {
+        if (!rect.contains(point)) {
             indicesLeftToPoint += rect.width() > 1 ? rect.width() : rect.height();
             continue;
         }
 
         found = true;
-        if ( rect.width() > 1 )
+        if (rect.width() > 1)
             indicesLeftToPoint += point.x() - rect.topLeft().x();
         else
             indicesLeftToPoint += point.y() - rect.topLeft().y();
@@ -731,27 +720,27 @@ int CellRegion::indexAtPoint( const QPoint &point ) const
 }
 
 #if 0 // Unused?
-static int rangeCharToInt( char c )
+static int rangeCharToInt(char c)
 {
     return (c >= 'A' && c <= 'Z') ? (c - 'A' + 1) : -1;
 }
 
-static int rangeStringToInt( const QString &string )
+static int rangeStringToInt(const QString &string)
 {
     int result = 0;
     const int size = string.size();
-    for ( int i = 0; i < size; i++ ) {
-        //kDebug(350001) << "---" << float( rangeCharToInt( string[i].toAscii() ) * pow( 10.0, ( size - i - 1 ) ) );
-        result += rangeCharToInt( string[i].toAscii() ) * pow( 10.0, ( size - i - 1 ) );
+    for (int i = 0; i < size; i++) {
+        //kDebug(350001) << "---" << float(rangeCharToInt(string[i].toAscii()) * pow(10.0, (size - i - 1)));
+        result += rangeCharToInt(string[i].toAscii()) * pow(10.0, (size - i - 1));
     }
     //kDebug(350001) << "+++++ result=" << result;
     return result;
 }
 
-static QString rangeIntToString( int i )
+static QString rangeIntToString(int i)
 {
-    QString tmp = QString::number( i );
-    for( int j = 0; j < tmp.size(); j++ ) {
+    QString tmp = QString::number(i);
+    for (int j = 0; j < tmp.size(); j++) {
         tmp[j] = 'A' + tmp[j].toAscii() - '1';
     }
 
@@ -760,26 +749,26 @@ static QString rangeIntToString( int i )
 }
 #endif
 
-int CellRegion::rangeCharToInt( char c )
+int CellRegion::rangeCharToInt(char c)
 {
     return (c >= 'A' && c <= 'Z') ? (c - 'A' + 1) : -1;
 }
 
-int CellRegion::rangeStringToInt( const QString &string )
+int CellRegion::rangeStringToInt(const QString &string)
 {
     int result = 0;
     const int size = string.size();
-    for ( int i = 0; i < size; i++ ) {
-        result += rangeCharToInt( string[i].toAscii() ) * pow( 10.0, ( size - i - 1 ) );
+    for (int i = 0; i < size; i++) {
+        result += rangeCharToInt(string[i].toAscii()) * pow(10.0, (size - i - 1));
     }
 
     return result;
 }
 
-QString CellRegion::rangeIntToString( int i )
+QString CellRegion::rangeIntToString(int i)
 {
-    QString tmp = QString::number( i );
-    for( int j = 0; j < tmp.size(); j++ ) {
+    QString tmp = QString::number(i);
+    for (int j = 0; j < tmp.size(); j++) {
         tmp[j] = 'A' + tmp[j].toAscii() - '1';
     }
 
@@ -787,10 +776,10 @@ QString CellRegion::rangeIntToString( int i )
 }
 
 // Return the symbolic name of any column.
-static QString columnName( uint column )
+static QString columnName(uint column)
 {
-    if ( column < 1 || column > 32767 )
-        return QString( "@@@" );
+    if (column < 1 || column > 32767)
+        return QString("@@@");
 
     QString   str;
     unsigned  digits = 1;
@@ -798,11 +787,11 @@ static QString columnName( uint column )
 
     column--;
 
-    for( unsigned limit = 26; column >= limit + offset; limit *= 26, ++digits )
+    for (unsigned limit = 26; column >= limit + offset; limit *= 26, ++digits)
         offset += limit;
 
-    for( unsigned col = column - offset; digits; --digits, col /= 26 )
-        str.prepend( QChar( 'A' + ( col % 26 ) ) );
+    for (unsigned col = column - offset; digits; --digits, col /= 26)
+        str.prepend(QChar('A' + (col % 26)));
 
     return str;
 }
