@@ -19,6 +19,8 @@
 #ifndef LOGINWINDOW_H
 #define LOGINWINDOW_H
 
+#include <onlinedocument.h>
+
 #include <QDialog>
 
 #include "ui_authenticationdialog.h"
@@ -30,7 +32,7 @@ class LoginWindow : public QDialog
     Q_OBJECT
 
 public:
-    LoginWindow(QWidget *parent = 0);
+    LoginWindow(OnlineDocument::DocumentType docType, QWidget *parent = 0);
     ~LoginWindow();
     GoogleDocumentService * googleService() {  return gdoc; }
     void showProgressIndicator(bool visible);
@@ -42,6 +44,7 @@ private slots:
     void updateProgress(QString msg);
 
 private:
+    OnlineDocument::DocumentType m_type;
     Ui_Dialog *m_authDialog;
     GoogleDocumentService *gdoc;
 };
