@@ -144,8 +144,8 @@ static const char * CURRENT_DTD_VERSION = "1.2";
 QList<Doc*> Doc::Private::s_docs;
 int Doc::Private::s_docId = 0;
 
-Doc::Doc(QWidget *parentWidget, QObject* parent, bool singleViewMode)
-        : DocBase(parentWidget, parent, singleViewMode)
+Doc::Doc(QObject* parent)
+        : DocBase(parent)
         , dd(new Private)
 {
     connect(d->map, SIGNAL(sheetAdded(Sheet*)), this, SLOT(sheetAdded(Sheet*)));
@@ -204,9 +204,10 @@ void Doc::initEmpty()
 
 void Doc::saveConfig()
 {
-    if (isEmbedded() || !isReadWrite())
+    if (!isReadWrite())
         return;
     KSharedConfigPtr config = Factory::global().config();
+    Q_UNUSED(config);
 }
 
 void Doc::initConfig()
@@ -214,7 +215,7 @@ void Doc::initConfig()
     KSharedConfigPtr config = Factory::global().config();
 
     const int page = config->group("Tables Page Layout").readEntry("Default unit page", 0);
-    setUnit(KoUnit((KoUnit::Unit) page));
+    setUnit(KoUnit::fromListForUi(page, KoUnit::HidePixel));
 }
 
 KoView* Doc::createViewInstance(QWidget* parent)
@@ -237,11 +238,6 @@ QGraphicsItem *Doc::createCanvasItem()
     return new CanvasItem(this);
 }
 
-bool Doc::saveChildren(KoStore* _store)
-{
-    return map()->saveChildren(_store);
-}
-
 int Doc::supportedSpecialFormats() const
 {
     return KoDocument::supportedSpecialFormats();
