@@ -297,14 +297,6 @@ bool KWOdfWriter::save(KoOdfWriteStore &odfStore, KoEmbeddedDocumentSaver &embed
         if (! mainTextFrame->frames().isEmpty() && mainTextFrame->frames().first()) {
             KoTextShapeData *shapeData = qobject_cast<KoTextShapeData *>(mainTextFrame->frames().first()->shape()->userData());
             if (shapeData) {
-                KWPageManager *pm = m_document->pageManager();
-                if (pm->pageCount()) { // make the first page refer to our page master
-                    QTextCursor cursor(shapeData->document());
-                    QTextBlockFormat tbf;
-                    KWPageStyle style = pm->pages().first().pageStyle();
-                    tbf.setProperty(KoParagraphStyle::MasterPageName, m_masterPages.value(style));
-                    cursor.mergeBlockFormat(tbf);
-                }
                 shapeData->saveOdf(context, m_document->documentRdfBase());
             }
         }
